@@ -17,14 +17,16 @@
 
 package opennlp.dl;
 
-public class SpanEnd {
+public record SpanEnd(int index, int characterEnd) {
 
-  private int index;
-  private int characterEnd;
-
-  public SpanEnd(int index, int characterEnd) {
-    this.index = index;
-    this.characterEnd = characterEnd;
+  @Deprecated(forRemoval = true)
+  public int getIndex() {
+    return index;
+  }
+  
+  @Deprecated(forRemoval = true)
+  public int getCharacterEnd() {
+    return characterEnd;
   }
 
   @Override
@@ -32,12 +34,4 @@ public class SpanEnd {
     return "index: " + index + "; character end: " + characterEnd;
   }
 
-  public int getIndex() {
-    return index;
-  }
-
-  public int getCharacterEnd() {
-    return characterEnd;
-  }
-
 }
