@@ -21,6 +21,9 @@ import java.io.IOException;
 import java.util.LinkedList;
 import java.util.List;
 
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
+
 import opennlp.tools.chunker.ChunkSample;
 import opennlp.tools.chunker.ChunkerCrossValidator;
 import opennlp.tools.chunker.ChunkerEvaluationMonitor;
@@ -29,25 +32,29 @@ import opennlp.tools.cmdline.AbstractCrossValidatorTool;
 import opennlp.tools.cmdline.CmdLineUtil;
 import opennlp.tools.cmdline.chunker.ChunkerCrossValidatorTool.CVToolParams;
 import opennlp.tools.cmdline.params.CVParams;
-import opennlp.tools.cmdline.params.DetailedFMeasureEvaluatorParams;
 import opennlp.tools.util.eval.EvaluationMonitor;
 import opennlp.tools.util.eval.FMeasure;
 import opennlp.tools.util.model.ModelUtil;
 
+
 public final class ChunkerCrossValidatorTool
     extends AbstractCrossValidatorTool<ChunkSample, CVToolParams> {
 
-  interface CVToolParams extends TrainingParams, CVParams, DetailedFMeasureEvaluatorParams {
+  interface CVToolParams extends TrainingParams, CVParams {
   }
 
+  private static final Logger logger = LoggerFactory.getLogger(ChunkerCrossValidatorTool.class);
+
   public ChunkerCrossValidatorTool() {
     super(ChunkSample.class, CVToolParams.class);
   }
 
+  @Override
   public String getShortDescription() {
     return "K-fold cross validator for the chunker";
   }
 
+  @Override
   public void run(String format, String[] args) {
     super.run(format, args);
 
@@ -57,14 +64,9 @@ public final class ChunkerCrossValidatorTool
     }
 
     List<EvaluationMonitor<ChunkSample>> listeners = new LinkedList<>();
-    ChunkerDetailedFMeasureListener detailedFMeasureListener = null;
     if (params.getMisclassified()) {
       listeners.add(new ChunkEvaluationErrorListener());
     }
-    if (params.getDetailedF()) {
-      detailedFMeasureListener = new ChunkerDetailedFMeasureListener();
-      listeners.add(detailedFMeasureListener);
-    }
 
     ChunkerCrossValidator validator;
 
@@ -74,7 +76,7 @@ public final class ChunkerCrossValidatorTool
 
       validator = new ChunkerCrossValidator(params.getLang(), mlParams,
           chunkerFactory,
-          listeners.toArray(new ChunkerEvaluationMonitor[listeners.size()]));
+          listeners.toArray(new ChunkerEvaluationMonitor[0]));
       validator.evaluate(sampleStream, params.getFolds());
     }
     catch (IOException e) {
@@ -88,11 +90,7 @@ public final class ChunkerCrossValidatorTool
       }
     }
 
-    if (detailedFMeasureListener == null) {
-      FMeasure result = validator.getFMeasure();
-      System.out.println(result);
-    } else {
-      System.out.println(detailedFMeasureListener);
-    }
+    FMeasure result = validator.getFMeasure();
+    logger.info(result.toString());
   }
 }
