@@ -25,6 +25,9 @@ import java.io.OutputStream;
 import java.util.LinkedList;
 import java.util.List;
 
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
+
 import opennlp.tools.cmdline.AbstractEvaluatorTool;
 import opennlp.tools.cmdline.CmdLineUtil;
 import opennlp.tools.cmdline.PerformanceMonitor;
@@ -40,20 +43,31 @@ import opennlp.tools.doccat.DocumentSample;
 import opennlp.tools.util.ObjectStream;
 import opennlp.tools.util.eval.EvaluationMonitor;
 
+/**
+ * A default {@link DocumentSample}-centric implementation of {@link AbstractEvaluatorTool}
+ * that prints to an output stream.
+ *
+ * @see AbstractEvaluatorTool
+ * @see EvalToolParams
+ */
 public final class DoccatEvaluatorTool extends
     AbstractEvaluatorTool<DocumentSample, EvalToolParams> {
 
   interface EvalToolParams extends EvaluatorParams, FineGrainedEvaluatorParams {
   }
 
+  private static final Logger logger = LoggerFactory.getLogger(DoccatEvaluatorTool.class);
+
   public DoccatEvaluatorTool() {
     super(DocumentSample.class, EvalToolParams.class);
   }
 
+  @Override
   public String getShortDescription() {
     return "Measures the performance of the Doccat model with the reference data";
   }
 
+  @Override
   public void run(String format, String[] args) {
     super.run(format, args);
 
@@ -82,21 +96,24 @@ public final class DoccatEvaluatorTool extends
 
     DocumentCategorizerEvaluator evaluator = new DocumentCategorizerEvaluator(
         new DocumentCategorizerME(model),
-        listeners.toArray(new DoccatEvaluationMonitor[listeners.size()]));
+        listeners.toArray(new DoccatEvaluationMonitor[0]));
 
     final PerformanceMonitor monitor = new PerformanceMonitor("doc");
 
-    try (ObjectStream<DocumentSample> measuredSampleStream = new ObjectStream<DocumentSample>() {
+    try (ObjectStream<DocumentSample> measuredSampleStream = new ObjectStream<>() {
 
+      @Override
       public DocumentSample read() throws IOException {
         monitor.incrementCounter();
         return sampleStream.read();
       }
 
+      @Override
       public void reset() throws IOException {
         sampleStream.reset();
       }
 
+      @Override
       public void close() throws IOException {
         sampleStream.close();
       }
@@ -104,7 +121,6 @@ public final class DoccatEvaluatorTool extends
       monitor.startAndPrintThroughput();
       evaluator.evaluate(measuredSampleStream);
     } catch (IOException e) {
-      System.err.println("failed");
       throw new TerminateToolException(-1, "IO error while reading test data: "
               + e.getMessage(), e);
     }
@@ -112,13 +128,11 @@ public final class DoccatEvaluatorTool extends
 
     monitor.stopAndPrintFinalResult();
 
-    System.out.println();
-
-    System.out.println(evaluator);
+    logger.info(evaluator.toString());
 
     if (reportListener != null) {
-      System.out.println("Writing fine-grained report to "
-          + params.getReportOutputFile().getAbsolutePath());
+      logger.info("Writing fine-grained report to {}",
+          params.getReportOutputFile().getAbsolutePath());
       reportListener.writeReport();
 
       try {
