@@ -20,6 +20,9 @@ package opennlp.tools.cmdline.postag;
 import java.io.File;
 import java.io.IOException;
 
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
+
 import opennlp.tools.cmdline.BasicCmdLineTool;
 import opennlp.tools.cmdline.CLI;
 import opennlp.tools.cmdline.CmdLineUtil;
@@ -34,31 +37,35 @@ import opennlp.tools.util.PlainTextByLineStream;
 
 public final class POSTaggerTool extends BasicCmdLineTool {
 
+  private static final Logger logger = LoggerFactory.getLogger(POSTaggerTool.class);
+
+  @Override
   public String getShortDescription() {
-    return "learnable part of speech tagger";
+    return "Learnable part of speech tagger";
   }
 
+  @Override
   public String getHelp() {
     return "Usage: " + CLI.CMD + " " + getName() + " model < sentences";
   }
 
+  @Override
   public void run(String[] args) {
 
     if (args.length != 1) {
-      System.out.println(getHelp());
+      logger.info(getHelp());
     } else {
 
       POSModel model = new POSModelLoader().load(new File(args[0]));
 
       POSTaggerME tagger = new POSTaggerME(model);
 
-      ObjectStream<String> lineStream;
       PerformanceMonitor perfMon = null;
 
-      try {
-        lineStream =
-            new PlainTextByLineStream(new SystemInputStreamFactory(), SystemInputStreamFactory.encoding());
-        perfMon = new PerformanceMonitor(System.err, "sent");
+      try (ObjectStream<String> lineStream = new PlainTextByLineStream(
+              new SystemInputStreamFactory(), SystemInputStreamFactory.encoding())) {
+
+        perfMon = new PerformanceMonitor("sent");
         perfMon.start();
         String line;
         while ((line = lineStream.read()) != null) {
@@ -67,7 +74,7 @@ public final class POSTaggerTool extends BasicCmdLineTool {
           String[] tags = tagger.tag(whitespaceTokenizerLine);
 
           POSSample sample = new POSSample(whitespaceTokenizerLine, tags);
-          System.out.println(sample);
+          logger.info(sample.toString());
 
           perfMon.incrementCounter();
         }
