@@ -23,42 +23,20 @@ import opennlp.tools.util.StringList;
 /**
  * An {@link Entry} is a {@link StringList} which can
  * optionally be mapped to attributes.
- *
- * {@link Entry}s is a read and written by the {@link DictionaryEntryPersistor}.
+ * <p>
+ * {@link Entry entries} are read and written by the {@link DictionaryEntryPersistor}.
  *
  * @see DictionaryEntryPersistor
  * @see Attributes
  */
-public class Entry {
+public record Entry(StringList tokens, Attributes attributes) {
 
-  private StringList tokens;
-  private Attributes attributes;
-
-  /**
-   * Initializes the current instance.
-   *
-   * @param tokens
-   * @param attributes
-   */
-  public Entry(StringList tokens, Attributes attributes) {
-    this.tokens = tokens;
-    this.attributes = attributes;
-  }
-
-  /**
-   * Retrieves the tokens.
-   *
-   * @return the tokens
-   */
+  @Deprecated(forRemoval = true)
   public StringList getTokens() {
     return tokens;
   }
-
-  /**
-   * Retrieves the {@link Attributes}.
-   *
-   * @return the {@link Attributes}
-   */
+  
+  @Deprecated(forRemoval = true)
   public Attributes getAttributes() {
     return attributes;
   }
