@@ -17,6 +17,7 @@
 
 package opennlp.tools.formats.nkjp;
 
+import java.io.BufferedInputStream;
 import java.io.File;
 import java.io.FileInputStream;
 import java.io.IOException;
@@ -61,8 +62,8 @@ public class NKJPSegmentationDocument {
 
     @Override
     public String toString() {
-      return doc + "#string-range(" + id + "," + Integer.toString(offset)
-          + "," + Integer.toString(length) + ")";
+      return doc + "#string-range(" + id + "," + offset
+          + "," + length + ")";
     }
   }
 
@@ -86,7 +87,7 @@ public class NKJPSegmentationDocument {
     Map<String, Map<String, Pointer>> sentences = new LinkedHashMap<>();
 
     try {
-      DocumentBuilder docBuilder = XmlUtil.createDocumentBuilder();;
+      DocumentBuilder docBuilder = XmlUtil.createDocumentBuilder();
       Document doc = docBuilder.parse(is);
 
       XPathFactory xPathfactory = XPathFactory.newInstance();
@@ -231,8 +232,8 @@ public class NKJPSegmentationDocument {
     }
 
     String docid = pieces[0];
-    int offset = 0;
-    int length = 0;
+    int offset;
+    int length;
     if (pieces.length == 3) {
       offset = Integer.parseInt(pieces[1]);
       length = Integer.parseInt(pieces[2]);
@@ -247,7 +248,7 @@ public class NKJPSegmentationDocument {
   }
 
   static NKJPSegmentationDocument parse(File file) throws IOException {
-    try (InputStream in = new FileInputStream(file)) {
+    try (InputStream in = new BufferedInputStream(new FileInputStream(file))) {
       return parse(in);
     }
   }
