@@ -17,25 +17,21 @@
 
 package opennlp.tools.langdetect;
 
-public class ProbingLanguageDetectionResult {
-  private final Language[] languages;
-  private final int length;
-
-  public ProbingLanguageDetectionResult(Language[] languages, int length) {
-    this.languages = languages;
-    this.length = length;
-  }
+/**
+ * A data container encapsulating language detection results.
+ *
+ * @param languages The {@link Language languages} detected.
+ * @param length    The length in codepoints of text processed.
+ */
+public record ProbingLanguageDetectionResult(Language[] languages, int length) {
 
+  @Deprecated(forRemoval = true)
   public Language[] getLanguages() {
     return languages;
   }
 
-  /**
-   *
-   * @return length in codepoints of text processed
-   */
+  @Deprecated(forRemoval = true)
   public int getLength() {
     return length;
   }
-
 }
