@@ -38,55 +38,68 @@ public class ArrayMath {
   }
 
   /**
-   * L1-norm
+   * Computes the L1-norm for a vector {@code v}.
+   *
+   * @param v The vector of {@code double} values.
+   * @return The computed L1-norm.
    */
   public static double l1norm(double[] v) {
     double norm = 0;
-    for (int i = 0; i < v.length; i++)
-      norm += StrictMath.abs(v[i]);
+    for (double value : v) norm += StrictMath.abs(value);
     return norm;
   }
 
   /**
-   * L2-norm
+   * Computes the L2-norm for a vector {@code v}.
+   *
+   * @param v The vector of {@code double} values.
+   * @return The computed L2-norm.
    */
   public static double l2norm(double[] v) {
     return StrictMath.sqrt(innerProduct(v, v));
   }
 
   /**
-   * Inverse L2-norm
+   * Computes the Inverse L2-norm for a vector {@code v}.
+   *
+   * @param v The vector of {@code double} values.
+   * @return The computed Inverse L2-norm.
    */
   public static double invL2norm(double[] v) {
     return 1 / l2norm(v);
   }
 
   /**
-   * Computes \log(\sum_{i=1}^n e^{x_i}) using a maximum-element trick
+   * Computes {@code \log(\sum_{i=1}^n e^{x_i})} using a maximum-element trick
    * to avoid arithmetic overflow.
    *
-   * @param x input vector
-   * @return log-sum of exponentials of vector elements
+   * @param x The vector of {@code double} values.
+   * @return The log-sum of exponentials of vector elements.
    */
   public static double logSumOfExps(double[] x) {
     double max = max(x);
     double sum = 0.0;
-    for (int i = 0; i < x.length; i++) {
-      if (x[i] != Double.NEGATIVE_INFINITY)
-        sum += StrictMath.exp(x[i] - max);
+    for (double v : x) {
+      if (v != Double.NEGATIVE_INFINITY)
+        sum += StrictMath.exp(v - max);
     }
     return max + StrictMath.log(sum);
   }
 
+  /**
+   * Finds the maximum element in a vector {@code x}.
+   * @param x The vector of {@code double} values.
+   * @return The maximum element in {@code x}.
+   */
   public static double max(double[] x) {
     int maxIdx = argmax(x);
     return x[maxIdx];
   }
 
   /**
-   * Find index of maximum element in the vector x
-   * @param x input vector
-   * @return index of the maximum element. Index of the first
+   * Finds the index of the maximum element in a vector {@code x}
+   * @param x The vector of {@code double} values.
+   * @return The index of the maximum element. Index of the first
    *     maximum element is returned if multiple maximums are found.
    */
   public static int argmax(double[] x) {
@@ -122,7 +135,10 @@ public class ArrayMath {
 
   // === Not really related to math ===
   /**
-   * Convert a list of Double objects into an array of primitive doubles
+   * Convert a list of {@link Double} objects into an array of primitive doubles.
+   *
+   * @param list The input vector of {@link Double values}.
+   * @return The {@code double[]}.
    */
   public static double[] toDoubleArray(List<Double> list) {
     double[] arr = new double[list.size()];
@@ -133,7 +149,10 @@ public class ArrayMath {
   }
 
   /**
-   *  Convert a list of Integer objects into an array of primitive integers
+   * Convert a list of {@link Integer} objects into an array of primitive integers.
+   *
+   * @param list The input vector of {@link Integer values}.
+   * @return The {@code int[]}.
    */
   public static int[] toIntArray(List<Integer> list) {
     int[] arr = new int[list.size()];
