@@ -27,9 +27,11 @@ import java.util.concurrent.ExecutorCompletionService;
 import java.util.concurrent.ExecutorService;
 import java.util.concurrent.Executors;
 
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
+
 import opennlp.tools.ml.AbstractEventTrainer;
 import opennlp.tools.ml.ArrayMath;
-import opennlp.tools.ml.model.AbstractModel;
 import opennlp.tools.ml.model.DataIndexer;
 import opennlp.tools.ml.model.EvalParameters;
 import opennlp.tools.ml.model.Event;
@@ -41,29 +43,30 @@ import opennlp.tools.ml.model.UniformPrior;
 import opennlp.tools.util.ObjectStream;
 import opennlp.tools.util.TrainingParameters;
 
-
 /**
- * An implementation of Generalized Iterative Scaling.  The reference paper
- * for this implementation was Adwait Ratnaparkhi's tech report at the
+ * An implementation of Generalized Iterative Scaling (GIS).
+ * <p>
+ * The reference paper for this implementation was Adwait Ratnaparkhi's tech report at the
  * University of Pennsylvania's Institute for Research in Cognitive Science,
- * and is available at <a href ="ftp://ftp.cis.upenn.edu/pub/ircs/tr/97-08.ps.Z"><code>ftp://ftp.cis.upenn.edu/pub/ircs/tr/97-08.ps.Z</code></a>.
+ * and is available at <a href ="ftp://ftp.cis.upenn.edu/pub/ircs/tr/97-08.ps.Z">
+ *   ftp://ftp.cis.upenn.edu/pub/ircs/tr/97-08.ps.Z</a>.
  * <p>
  * The slack parameter used in the above implementation has been removed by default
  * from the computation and a method for updating with Gaussian smoothing has been
  * added per Investigating GIS and Smoothing for Maximum Entropy Taggers, Clark and Curran (2002).
- * <a href="http://acl.ldc.upenn.edu/E/E03/E03-1071.pdf"><code>http://acl.ldc.upenn.edu/E/E03/E03-1071.pdf</code></a>
- * The slack parameter can be used by setting <code>useSlackParameter</code> to true.
- * Gaussian smoothing can be used by setting <code>useGaussianSmoothing</code> to true.
+ * <a href="http://acl.ldc.upenn.edu/E/E03/E03-1071.pdf">http://acl.ldc.upenn.edu/E/E03/E03-1071.pdf</a>.
  * <p>
- * A prior can be used to train models which converge to the distribution which minimizes the
+ * The slack parameter can be used by setting {@code useSlackParameter} to {@code true}.
+ * Gaussian smoothing can be used by setting {@code useGaussianSmoothing} to {@code true}.
+ * <p>
+ * A {@link Prior} can be used to train models which converge to the distribution which minimizes the
  * relative entropy between the distribution specified by the empirical constraints of the training
- * data and the specified prior.  By default, the uniform distribution is used as the prior.
+ * data and the specified prior. By default, the uniform distribution is used as the prior.
  */
 public class GISTrainer extends AbstractEventTrainer {
 
-  @Deprecated
-  public static final String OLD_LL_THRESHOLD_PARAM = "llthreshold";
-  
+  private static final Logger logger = LoggerFactory.getLogger(GISTrainer.class);
+
   public static final String LOG_LIKELIHOOD_THRESHOLD_PARAM = "LLThreshold";
   public static final double LOG_LIKELIHOOD_THRESHOLD_DEFAULT = 0.0001;
   private double llThreshold = 0.0001;
@@ -82,7 +85,7 @@ public class GISTrainer extends AbstractEventTrainer {
   // actually didn't see.  Defaulted to 0.1.
   private double _smoothingObservation = 0.1;
   /**
-   * Number of unique events which occured in the event set.
+   * Number of unique events which occurred in the event set.
    */
   private int numUniqueEvents;
   /**
@@ -160,36 +163,30 @@ public class GISTrainer extends AbstractEventTrainer {
   private static final double GAUSSIAN_SMOOTHING_SIGMA_DEFAULT = 2.0;
   
   /**
-   * Creates a new <code>GISTrainer</code> instance which does not print
-   * progress messages about training to STDOUT.
+   * Initializes a {@link GISTrainer}.
+   * <p>
+   * <b>Note:</b><br>
+   * The resulting instance does not print progress messages about training to STDOUT.
    */
   public GISTrainer() {
-    printMessages = false;
   }
 
+  /**
+   * {@inheritDoc}
+   */
   @Override
   public boolean isSortAndMerge() {
     return true;
   }
 
+  /**
+   * {@inheritDoc}
+   */
   @Override
   public void init(TrainingParameters trainingParameters, Map<String, String> reportMap) {
     super.init(trainingParameters, reportMap);
 
-    // Just in case someone is using "llthreshold" instead of LLThreshold...
-    // this warning can be removed in a future version of OpenNLP.
-    if (trainingParameters.getDoubleParameter(OLD_LL_THRESHOLD_PARAM, -1.) > 0. ) {
-      display("WARNING: the training parameter: " + OLD_LL_THRESHOLD_PARAM + 
-          " has been deprecated.  Please use " +
-          LOG_LIKELIHOOD_THRESHOLD_DEFAULT + " instead");
-      // if they didn't supply a value for both llthreshold AND LLThreshold  copy it over..
-      if (trainingParameters.getDoubleParameter(LOG_LIKELIHOOD_THRESHOLD_PARAM, -1.) < 0. ) {
-        trainingParameters.put(LOG_LIKELIHOOD_THRESHOLD_PARAM,
-            trainingParameters.getDoubleParameter(OLD_LL_THRESHOLD_PARAM, LOG_LIKELIHOOD_THRESHOLD_DEFAULT));
-      }
-    }
-
-    llThreshold = trainingParameters.getDoubleParameter(LOG_LIKELIHOOD_THRESHOLD_PARAM, 
+    llThreshold = trainingParameters.getDoubleParameter(LOG_LIKELIHOOD_THRESHOLD_PARAM,
         LOG_LIKELIHOOD_THRESHOLD_DEFAULT);
 
     useSimpleSmoothing = trainingParameters.getBooleanParameter(SMOOTHING_PARAM, SMOOTHING_DEFAULT);
@@ -208,33 +205,26 @@ public class GISTrainer extends AbstractEventTrainer {
     if (useSimpleSmoothing && useGaussianSmoothing) 
       throw new RuntimeException("Cannot set both Gaussian smoothing and Simple smoothing");
   }
-  
+
+  /**
+   * {@inheritDoc}
+   */
   @Override
   public MaxentModel doTrain(DataIndexer indexer) throws IOException {
     int iterations = getIterations();
 
     int threads = trainingParameters.getIntParameter(TrainingParameters.THREADS_PARAM, 1);
-    AbstractModel model = trainModel(iterations, indexer, threads);
-
-    return model;
-  }
-
-  /**
-   * Creates a new <code>GISTrainer</code> instance.
-   *
-   * @param printMessages sends progress messages about training to
-   *                      STDOUT when true; trains silently otherwise.
-   */
-  GISTrainer(boolean printMessages) {
-    this.printMessages = printMessages;
+    return trainModel(iterations, indexer, threads);
   }
 
   /**
    * Sets whether this trainer will use smoothing while training the model.
+   * <p>
+   * <b>Note:</b><br>
    * This can improve model accuracy, though training will potentially take
-   * longer and use more memory.  Model size will also be larger.
+   * longer and use more memory. Model size will also be larger.
    *
-   * @param smooth true if smoothing is desired, false if not
+   * @param smooth {@code true} if smoothing is desired, {@code false} if not.
    */
   public void setSmoothing(boolean smooth) {
     useSimpleSmoothing = smooth;
@@ -242,10 +232,12 @@ public class GISTrainer extends AbstractEventTrainer {
 
   /**
    * Sets whether this trainer will use smoothing while training the model.
+   * <p>
+   * <b>Note:</b><br>
    * This can improve model accuracy, though training will potentially take
-   * longer and use more memory.  Model size will also be larger.
+   * longer and use more memory. Model size will also be larger.
    *
-   * @param timesSeen the "number" of times we want the trainer to imagine
+   * @param timesSeen The "number" of times we want the trainer to imagine
    *                  it saw a feature that it actually didn't see
    */
   public void setSmoothingObservation(double timesSeen) {
@@ -254,8 +246,12 @@ public class GISTrainer extends AbstractEventTrainer {
 
   /**
    * Sets whether this trainer will use smoothing while training the model.
+   * <p>
+   * <b>Note:</b><br>
    * This can improve model accuracy, though training will potentially take
-   * longer and use more memory.  Model size will also be larger.
+   * longer and use more memory. Model size will also be larger.
+   *
+   * @param sigmaValue The Gaussian sigma value used for smoothing.
    */
   public void setGaussianSigma(double sigmaValue) {
     useGaussianSmoothing = true;
@@ -263,14 +259,14 @@ public class GISTrainer extends AbstractEventTrainer {
   }
 
   /**
-   * Train a model using the GIS algorithm, assuming 100 iterations and no
+   * Trains a model using the GIS algorithm, assuming 100 iterations and no
    * cutoff.
    *
-   * @param eventStream
-   *          The EventStream holding the data on which this model will be
-   *          trained.
-   * @return The newly trained model, which can be used immediately or saved to
-   *         disk using an opennlp.tools.ml.maxent.io.GISModelWriter object.
+   * @param eventStream The {@link ObjectStream eventStream} holding the data
+   *                    on which this model will be trained.
+   *                    
+   * @return A trained {@link GISModel} which can be used immediately or saved to
+   *         disk using an {@link opennlp.tools.ml.maxent.io.GISModelWriter}.
    */
   public GISModel trainModel(ObjectStream<Event> eventStream) throws IOException {
     return trainModel(eventStream, 100, 0);
@@ -280,10 +276,12 @@ public class GISTrainer extends AbstractEventTrainer {
    * Trains a GIS model on the event in the specified event stream, using the specified number
    * of iterations and the specified count cutoff.
    *
-   * @param eventStream A stream of all events.
+   * @param eventStream A {@link ObjectStream stream} of all events.
    * @param iterations  The number of iterations to use for GIS.
    * @param cutoff      The number of times a feature must occur to be included.
-   * @return A GIS model trained with specified
+   *
+   * @return A trained {@link GISModel} which can be used immediately or saved to
+   *         disk using an {@link opennlp.tools.ml.maxent.io.GISModelWriter}.
    */
   public GISModel trainModel(ObjectStream<Event> eventStream, int iterations,
                              int cutoff) throws IOException {
@@ -298,38 +296,44 @@ public class GISTrainer extends AbstractEventTrainer {
   }
 
   /**
-   * Train a model using the GIS algorithm.
+   * Trains a model using the GIS algorithm.
    *
    * @param iterations The number of GIS iterations to perform.
-   * @param di         The data indexer used to compress events in memory.
-   * @return The newly trained model, which can be used immediately or saved
-   * to disk using an opennlp.tools.ml.maxent.io.GISModelWriter object.
+   * @param di         The {@link DataIndexer} used to compress events in memory.
+   *                   
+   * @return A trained {@link GISModel} which can be used immediately or saved to
+   *         disk using an {@link opennlp.tools.ml.maxent.io.GISModelWriter}.
+   * @throws IllegalArgumentException Thrown if parameters were invalid.
    */
   public GISModel trainModel(int iterations, DataIndexer di) {
     return trainModel(iterations, di, new UniformPrior(), 1);
   }
 
   /**
-   * Train a model using the GIS algorithm.
+   * Trains a model using the GIS algorithm.
    *
    * @param iterations The number of GIS iterations to perform.
-   * @param di         The data indexer used to compress events in memory.
-   * @param threads
-   * @return The newly trained model, which can be used immediately or saved
-   * to disk using an opennlp.tools.ml.maxent.io.GISModelWriter object.
+   * @param di         The {@link DataIndexer} used to compress events in memory.
+   * @param threads    The number of thread to train with. Must be greater than {@code 0}.
+   *
+   * @return A trained {@link GISModel} which can be used immediately or saved to
+   *         disk using an {@link opennlp.tools.ml.maxent.io.GISModelWriter}.
+   * @throws IllegalArgumentException Thrown if parameters were invalid.
    */
   public GISModel trainModel(int iterations, DataIndexer di, int threads) {
     return trainModel(iterations, di, new UniformPrior(), threads);
   }
 
   /**
-   * Train a model using the GIS algorithm.
+   * Trains a model using the GIS algorithm.
    *
    * @param iterations The number of GIS iterations to perform.
-   * @param di         The data indexer used to compress events in memory.
-   * @param modelPrior The prior distribution used to train this model.
-   * @return The newly trained model, which can be used immediately or saved
-   * to disk using an opennlp.tools.ml.maxent.io.GISModelWriter object.
+   * @param di         The {@link DataIndexer} used to compress events in memory.
+   * @param modelPrior The {@link Prior} distribution used to train this model.
+   *                   
+   * @return A trained {@link GISModel} which can be used immediately or saved to
+   *         disk using an {@link opennlp.tools.ml.maxent.io.GISModelWriter}.
+   * @throws IllegalArgumentException Thrown if parameters were invalid.
    */
   public GISModel trainModel(int iterations, DataIndexer di, Prior modelPrior, int threads) {
 
@@ -340,11 +344,11 @@ public class GISTrainer extends AbstractEventTrainer {
     modelExpects = new MutableContext[threads][];
 
     /* Incorporate all of the needed info *****/
-    display("Incorporating indexed data for training...  \n");
+    logger.info("Incorporating indexed data for training...");
     contexts = di.getContexts();
     values = di.getValues();
     /*
-    The number of times a predicate occured in the training data.
+    The number of times a predicate occurred in the training data.
    */
     int[] predicateCounts = di.getPredCounts();
     numTimesEventsSeen = di.getNumTimesEventsSeen();
@@ -370,7 +374,7 @@ public class GISTrainer extends AbstractEventTrainer {
         }
       }
     }
-    display("done.\n");
+    logger.info("done.");
 
     outcomeLabels = di.getOutcomeLabels();
     outcomeList = di.getOutcomeList();
@@ -380,9 +384,9 @@ public class GISTrainer extends AbstractEventTrainer {
     prior.setLabels(outcomeLabels, predLabels);
     numPreds = predLabels.length;
 
-    display("\tNumber of Event Tokens: " + numUniqueEvents + "\n");
-    display("\t    Number of Outcomes: " + numOutcomes + "\n");
-    display("\t  Number of Predicates: " + numPreds + "\n");
+    logger.info("\tNumber of Event Tokens: {} " +
+        "\n\t Number of Outcomes: {} " +
+        "\n\t Number of Predicates: {}", numUniqueEvents, numOutcomes, numPreds);
 
     // set up feature arrays
     float[][] predCount = new float[numPreds][numOutcomes];
@@ -462,13 +466,13 @@ public class GISTrainer extends AbstractEventTrainer {
       }
     }
 
-    display("...done.\n");
+    logger.info("...done.");
 
     /* Find the parameters *****/
     if (threads == 1) {
-      display("Computing model parameters ...\n");
+      logger.info("Computing model parameters ...");
     } else {
-      display("Computing model parameters in " + threads + " threads...\n");
+      logger.info("Computing model parameters in {} threads...", threads);
     }
 
     findParameters(iterations, correctionConstant);
@@ -484,7 +488,7 @@ public class GISTrainer extends AbstractEventTrainer {
 
     ExecutorService executor = Executors.newFixedThreadPool(threads, runnable -> {
       Thread thread = new Thread(runnable);
-      thread.setName("opennlp.tools.ml.maxent.ModelExpactationComputeTask.nextIteration()");
+      thread.setName("opennlp.tools.ml.maxent.ModelExpectationComputeTask.nextIteration()");
       thread.setDaemon(true);
       return thread;
     });
@@ -493,19 +497,12 @@ public class GISTrainer extends AbstractEventTrainer {
         new ExecutorCompletionService<>(executor);
     double prevLL = 0.0;
     double currLL;
-    display("Performing " + iterations + " iterations.\n");
+    logger.info("Performing {} iterations.", iterations);
     for (int i = 1; i <= iterations; i++) {
-      if (i < 10) {
-        display("  " + i + ":  ");
-      } else if (i < 100) {
-        display(" " + i + ":  ");
-      } else {
-        display(i + ":  ");
-      }
-      currLL = nextIteration(correctionConstant, completionService);
+      currLL = nextIteration(correctionConstant, completionService, i);
       if (i > 1) {
         if (prevLL > currLL) {
-          System.err.println("Model Diverging: loglikelihood decreased");
+          logger.warn("Model Diverging: loglikelihood decreased");
           break;
         }
         if (currLL - prevLL < llThreshold) {
@@ -530,14 +527,14 @@ public class GISTrainer extends AbstractEventTrainer {
     double modelValue = modelExpects[0][predicate].getParameters()[oid];
     double observedValue = observedExpects[predicate].getParameters()[oid];
     for (int i = 0; i < 50; i++) {
-      double tmp = modelValue * Math.exp(correctionConstant * x0);
+      double tmp = modelValue * StrictMath.exp(correctionConstant * x0);
       double f = tmp + (param + x0) / sigma - observedValue;
       double fp = tmp * correctionConstant + 1 / sigma;
       if (fp == 0) {
         break;
       }
       double x = x0 - f / fp;
-      if (Math.abs(x - x0) < 0.000001) {
+      if (StrictMath.abs(x - x0) < 0.000001) {
         x0 = x;
         break;
       }
@@ -546,9 +543,10 @@ public class GISTrainer extends AbstractEventTrainer {
     return x0;
   }
 
-  /* Compute one iteration of GIS and retutn log-likelihood.*/
+  /* Compute one iteration of GIS and return log-likelihood.*/
   private double nextIteration(double correctionConstant,
-                               CompletionService<ModelExpectationComputeTask> completionService) {
+                               CompletionService<ModelExpectationComputeTask> completionService,
+                               int iteration) {
     // compute contribution of p(a|b_i) for each feature and the new
     // correction parameter
     double loglikelihood = 0.0;
@@ -579,9 +577,8 @@ public class GISTrainer extends AbstractEventTrainer {
         finishedTask = completionService.take().get();
       } catch (InterruptedException e) {
         // TODO: We got interrupted, but that is currently not really supported!
-        // For now we just print the exception and fail hard. We hopefully soon
+        // For now we fail hard. We hopefully soon
         // handle this case properly!
-        e.printStackTrace();
         throw new IllegalStateException("Interruption is not supported!", e);
       } catch (ExecutionException e) {
         // Only runtime exception can be thrown during training, if one was thrown
@@ -596,8 +593,6 @@ public class GISTrainer extends AbstractEventTrainer {
       loglikelihood += finishedTask.getLoglikelihood();
     }
 
-    display(".");
-
     // merge the results of the two computations
     for (int pi = 0; pi < numPreds; pi++) {
       int[] activeOutcomes = params[pi].getOutcomes();
@@ -609,8 +604,6 @@ public class GISTrainer extends AbstractEventTrainer {
       }
     }
 
-    display(".");
-
     // compute the new parameter values
     for (int pi = 0; pi < numPreds; pi++) {
       double[] observed = observedExpects[pi].getParameters();
@@ -621,10 +614,10 @@ public class GISTrainer extends AbstractEventTrainer {
           params[pi].updateParameter(aoi, gaussianUpdate(pi, aoi, correctionConstant));
         } else {
           if (model[aoi] == 0) {
-            System.err.println("Model expects == 0 for " + predLabels[pi] + " " + outcomeLabels[aoi]);
+            logger.warn("Model expects == 0 for {} {}", predLabels[pi], outcomeLabels[aoi]);
           }
-          //params[pi].updateParameter(aoi,(Math.log(observed[aoi]) - Math.log(model[aoi])));
-          params[pi].updateParameter(aoi, ((Math.log(observed[aoi]) - Math.log(model[aoi]))
+          //params[pi].updateParameter(aoi,(StrictMath.log(observed[aoi]) - StrictMath.log(model[aoi])));
+          params[pi].updateParameter(aoi, ((StrictMath.log(observed[aoi]) - StrictMath.log(model[aoi]))
               / correctionConstant));
         }
 
@@ -635,17 +628,12 @@ public class GISTrainer extends AbstractEventTrainer {
       }
     }
 
-    display(". loglikelihood=" + loglikelihood + "\t" + ((double) numCorrect / numEvents) + "\n");
+    logger.info("{} - loglikelihood={}\t{}",
+        iteration, loglikelihood, ((double) numCorrect / numEvents));
 
     return loglikelihood;
   }
 
-  protected void display(String s) {
-    if (printMessages) {
-      System.out.print(s);
-    }
-  }
-
   private class ModelExpectationComputeTask implements Callable<ModelExpectationComputeTask> {
 
     private final int startIndex;
@@ -695,14 +683,13 @@ public class GISTrainer extends AbstractEventTrainer {
           }
         }
 
-        loglikelihood += Math.log(modelDistribution[outcomeList[ei]]) * numTimesEventsSeen[ei];
+        loglikelihood += StrictMath.log(modelDistribution[outcomeList[ei]]) * numTimesEventsSeen[ei];
 
         numEvents += numTimesEventsSeen[ei];
-        if (printMessages) {
-          int max = ArrayMath.argmax(modelDistribution);
-          if (max == outcomeList[ei]) {
-            numCorrect += numTimesEventsSeen[ei];
-          }
+
+        int max = ArrayMath.argmax(modelDistribution);
+        if (max == outcomeList[ei]) {
+          numCorrect += numTimesEventsSeen[ei];
         }
 
       }
