@@ -21,13 +21,30 @@ import opennlp.tools.ml.ArrayMath;
 import opennlp.tools.ml.model.AbstractModel;
 import opennlp.tools.ml.model.Context;
 
+/**
+ * A maximum entropy model which has been trained using the Quasi Newton (QN) algorithm.
+ *
+ * @see AbstractModel
+ */
 public class QNModel extends AbstractModel {
 
+  /**
+   * Initializes a {@link QNModel} with the specified parameters, outcome names, and
+   * predicate/feature labels.
+   *
+   * @param params The {@link Context parameters} of the model.
+   * @param predLabels The names of the predicates used in this model.
+   * @param outcomeNames The names of the outcomes this model predicts.
+   */
   public QNModel(Context[] params, String[] predLabels, String[] outcomeNames) {
     super(params, predLabels, outcomeNames);
     this.modelType = ModelType.MaxentQn;
   }
 
+  /**
+   * {@inheritDoc}
+   */
+  @Override
   public int getNumOutcomes() {
     return this.outcomeNames.length;
   }
@@ -36,28 +53,38 @@ public class QNModel extends AbstractModel {
     return pmap.get(predicate);
   }
 
+  /**
+   * {@inheritDoc}
+   */
+  @Override
   public double[] eval(String[] context) {
     return eval(context, new double[evalParams.getNumOutcomes()]);
   }
 
+  /**
+   * {@inheritDoc}
+   */
+  @Override
   public double[] eval(String[] context, double[] probs) {
     return eval(context, null, probs);
   }
 
+  /**
+   * {@inheritDoc}
+   */
+  @Override
   public double[] eval(String[] context, float[] values) {
     return eval(context, values, new double[evalParams.getNumOutcomes()]);
   }
 
   /**
-   * Model evaluation which should be used during inference.
-   * @param context
-   *          The predicates which have been observed at the present
-   *          decision point.
-   * @param values
-   *          Weights of the predicates which have been observed at
-   *          the present decision point.
-   * @param probs
-   *          Probability for outcomes.
+   * Evaluates which should be used during inference.
+   * 
+   * @param context The predicates which have been observed at the present
+   *                decision point.
+   * @param values The weights of the predicates which have been observed at
+   *               the present decision point.
+   * @param probs The probability for outcomes.
    * @return Normalized probabilities for the outcomes given the context.
    */
   private double[] eval(String[] context, float[] values, double[] probs) {
@@ -86,21 +113,15 @@ public class QNModel extends AbstractModel {
   }
 
   /**
-   * Model evaluation which should be used during training to report model accuracy.
-   * @param context
-   *          Indices of the predicates which have been observed at the present
-   *          decision point.
-   * @param values
-   *          Weights of the predicates which have been observed at
-   *          the present decision point.
-   * @param probs
-   *          Probability for outcomes
-   * @param nOutcomes
-   *          Number of outcomes
-   * @param nPredLabels
-   *          Number of unique predicates
-   * @param parameters
-   *          Model parameters
+   * Evaluates which should be used during training to report model accuracy.
+   * @param context The indices of the predicates which have been observed at the present
+   *                decision point.
+   * @param values The weights of the predicates which have been observed at
+   *               the present decision point.
+   * @param probs The probability for outcomes.
+   * @param nOutcomes The number of outcomes.
+   * @param nPredLabels The number of unique predicates.
+   * @param parameters The model parameters.
    * @return Normalized probabilities for the outcomes given the context.
    */
   static double[] eval(int[] context, float[] values, double[] probs,
