@@ -25,6 +25,9 @@ import java.util.Objects;
 
 import opennlp.tools.ml.ArrayMath;
 
+/**
+ * A basic {@link MaxentModel} implementation.
+ */
 public abstract class AbstractModel implements MaxentModel {
 
   /** Mapping between predicates/contexts and an integer representing them. */
@@ -41,6 +44,14 @@ public abstract class AbstractModel implements MaxentModel {
   /** The type of the model. */
   protected ModelType modelType;
 
+  /**
+   * Initializes an {@link AbstractModel}.
+   *
+   * @param params The {@link Context[] parameters} to set.
+   * @param predLabels The predicted labels.
+   * @param pmap A {@link Map} that provides a mapping between predicates and contexts.
+   * @param outcomeNames The names of the outcomes.
+   */
   protected AbstractModel(Context[] params, String[] predLabels,
       Map<String, Context> pmap, String[] outcomeNames) {
     this.pmap = pmap;
@@ -48,6 +59,13 @@ public abstract class AbstractModel implements MaxentModel {
     this.evalParams = new EvalParameters(params,outcomeNames.length);
   }
 
+  /**
+   * Initializes an {@link AbstractModel}.
+   *
+   * @param params The {@link Context parameters} to set.
+   * @param predLabels The predicted labels.
+   * @param outcomeNames The names of the outcomes.
+   */
   public AbstractModel(Context[] params, String[] predLabels, String[] outcomeNames) {
     init(predLabels, params, outcomeNames);
     this.evalParams = new EvalParameters(params, outcomeNames.length);
@@ -72,29 +90,32 @@ public abstract class AbstractModel implements MaxentModel {
    *            method.
    * @return    The name of the most likely outcome.
    */
+  @Override
   public final String getBestOutcome(double[] ocs) {
     return outcomeNames[ArrayMath.argmax(ocs)];
   }
 
+  /**
+   * @return Retrieves the {@link ModelType}.
+   */
   public ModelType getModelType() {
     return modelType;
   }
 
   /**
-   * Return a string matching all the outcome names with all the
-   * probabilities produced by the <code>eval(String[] context)</code>
-   * method.
+   * Retrieves a string matching all the outcome names with all the
+   * probabilities produced by the {@link #eval(String[])} method.
    *
-   * @param ocs A <code>double[]</code> as returned by the
-   *            <code>eval(String[] context)</code>
-   *            method.
+   * @param ocs A {@code double[]} as returned by the
+   *            {@link #eval(String[])} method.
    * @return    String containing outcome names paired with the normalized
-   *            probability (contained in the <code>double[] ocs</code>)
+   *            probability (contained in the {@code double[] ocs})
    *            for each one.
    */
+  @Override
   public final String getAllOutcomes(double[] ocs) {
     if (ocs.length != outcomeNames.length) {
-      return "The double array sent as a parameter to GISModel.getAllOutcomes() " +
+      return "The double array sent as a parameter to AbstractModel.getAllOutcomes() " +
           "must not have been produced by this model.";
     }
     else {
@@ -109,23 +130,21 @@ public abstract class AbstractModel implements MaxentModel {
   }
 
   /**
-   * Return the name of an outcome corresponding to an int id.
-   *
    * @param i An outcome id.
-   * @return  The name of the outcome associated with that id.
+   * @return  Retrieves the name of the outcome associated with that id.
    */
+  @Override
   public final String getOutcome(int i) {
     return outcomeNames[i];
   }
 
   /**
-   * Gets the index associated with the String name of the given outcome.
+   * @param outcome The String name of the outcome for which the index is desired.
    *
-   * @param outcome the String name of the outcome for which the
-   *          index is desired
-   * @return the index if the given outcome label exists for this
-   *     model, -1 if it does not.
+   * @return Retrieves the index if the given {@code outcome} label exists for this
+   *         model, {@code -1} if it does not.
    **/
+  @Override
   public int getIndex(String outcome) {
     for (int i = 0; i < outcomeNames.length; i++) {
       if (outcomeNames[i].equals(outcome))
@@ -134,26 +153,27 @@ public abstract class AbstractModel implements MaxentModel {
     return -1;
   }
 
+  @Override
   public int getNumOutcomes() {
     return evalParams.getNumOutcomes();
   }
 
   /**
    * Provides the fundamental data structures which encode the maxent model
-   * information.  This method will usually only be needed by
-   * GISModelWriters.  The following values are held in the Object array
-   * which is returned by this method:
+   * information. Note: This method will usually only be needed by
+   * {@link opennlp.tools.ml.maxent.io.GISModelWriter GIS model writers}.
+   * <p>
+   * The following values are held in the Object array which is returned by this method:
    * <ul>
-   * <li>index 0: opennlp.tools.ml.maxent.Context[] containing the model
-   *            parameters
-   * <li>index 1: java.util.Map containing the mapping of model predicates
-   *            to unique integers
-   * <li>index 2: java.lang.String[] containing the names of the outcomes,
+   * <li>index 0: {@link Context} array containing the model parameters.</li>
+   * <li>index 1: {@link Map} containing the mapping of model predicates
+   *            to unique integers.</li>
+   * <li>index 2: {@link String} array containing the names of the outcomes,
    *            stored in the index of the array which represents their
-   *            unique ids in the model.
+   *            unique ids in the model.</li>
    * </ul>
    *
-   * @return An Object[] with the values as described above.
+   * @return An {@link Object} array with the values as described above.
    */
   public final Object[] getDataStructures() {
     Object[] data = new Object[3];
@@ -174,8 +194,7 @@ public abstract class AbstractModel implements MaxentModel {
       return true;
     }
 
-    if (obj instanceof AbstractModel) {
-      AbstractModel model = (AbstractModel) obj;
+    if (obj instanceof AbstractModel model) {
 
       return pmap.equals(model.pmap) && Objects.deepEquals(outcomeNames, model.outcomeNames)
           && Objects.equals(prior, model.prior);
