@@ -19,6 +19,9 @@ package opennlp.tools.ml.perceptron;
 
 import java.io.IOException;
 
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
+
 import opennlp.tools.ml.AbstractEventTrainer;
 import opennlp.tools.ml.ArrayMath;
 import opennlp.tools.ml.model.AbstractModel;
@@ -28,15 +31,21 @@ import opennlp.tools.ml.model.MutableContext;
 import opennlp.tools.util.TrainingParameters;
 
 /**
- * Trains models using the perceptron algorithm.  Each outcome is represented as
- * a binary perceptron classifier.  This supports standard (integer) weighting as well
- * average weighting as described in:
+ * Trains {@link PerceptronModel models} using the perceptron algorithm.
+ * <p>
+ * Each outcome is represented as a binary perceptron classifier.
+ * This supports standard (integer) weighting as well average weighting as described in:
+ * <p>
  * Discriminative Training Methods for Hidden Markov Models: Theory and Experiments
  * with the Perceptron Algorithm. Michael Collins, EMNLP 2002.
  *
+ * @see PerceptronModel
+ * @see AbstractEventTrainer
  */
 public class PerceptronTrainer extends AbstractEventTrainer {
 
+  private static final Logger logger = LoggerFactory.getLogger(PerceptronTrainer.class);
+
   public static final String PERCEPTRON_VALUE = "PERCEPTRON";
   public static final double TOLERANCE_DEFAULT = .00001;
 
@@ -61,7 +70,7 @@ public class PerceptronTrainer extends AbstractEventTrainer {
   /** Records the num of times an event has been seen for each event i, in context[i]. */
   private int[] numTimesEventsSeen;
 
-  /** Stores the String names of the outcomes.  The GIS only tracks outcomes
+  /** Stores the String names of the outcomes. The GIS only tracks outcomes
   as ints, and so this array is needed to save the model to disk and
   thereby allow users to know what the outcome was in human
   understandable terms. */
@@ -79,13 +88,28 @@ public class PerceptronTrainer extends AbstractEventTrainer {
 
   private boolean useSkippedlAveraging;
 
+  /**
+   * Instantiates a {@link PerceptronTrainer} with default training parameters.
+   */
   public PerceptronTrainer() {
   }
 
+  /**
+   * Instantiates a {@link PerceptronTrainer} with specific
+   * {@link TrainingParameters}.
+   *
+   * @param parameters The {@link TrainingParameters parameter} to use.
+   */
   public PerceptronTrainer(TrainingParameters parameters) {
     super(parameters);
   }
 
+  /**
+   * {@inheritDoc}
+   *
+   * @throws IllegalArgumentException Thrown if the algorithm name is not equal to
+   *                                  {{@link #PERCEPTRON_VALUE}}.
+   */
   @Override
   public void validate() {
     super.validate();
@@ -98,34 +122,17 @@ public class PerceptronTrainer extends AbstractEventTrainer {
     }
   }
 
-  @Deprecated
   @Override
-  public boolean isValid() {
-    if (!super.isValid()) {
-      return false;
-    }
-
-    String algorithmName = getAlgorithm();
-    if (algorithmName != null) {
-      return PERCEPTRON_VALUE.equals(algorithmName);
-    }
-    else {
-      return true;
-    }
-  }
-
   public boolean isSortAndMerge() {
     return false;
   }
 
+  @Override
   public AbstractModel doTrain(DataIndexer indexer) throws IOException {
     int iterations = getIterations();
     int cutoff = getCutoff();
 
-    AbstractModel model;
-
     boolean useAverage = trainingParameters.getBooleanParameter("UseAverage", true);
-
     boolean useSkippedAveraging = trainingParameters.getBooleanParameter("UseSkippedAveraging", false);
 
     // overwrite otherwise it might not work
@@ -133,7 +140,6 @@ public class PerceptronTrainer extends AbstractEventTrainer {
       useAverage = true;
 
     double stepSizeDecrease = trainingParameters.getDoubleParameter("StepSizeDecrease", 0);
-
     double tolerance = trainingParameters.getDoubleParameter("Tolerance",
         PerceptronTrainer.TOLERANCE_DEFAULT);
 
@@ -144,18 +150,18 @@ public class PerceptronTrainer extends AbstractEventTrainer {
 
     this.setTolerance(tolerance);
 
-    model = this.trainModel(iterations, indexer, cutoff, useAverage);
-
-    return model;
+    return this.trainModel(iterations, indexer, cutoff, useAverage);
   }
 
-  // << members related to AbstractSequenceTrainer
+  // << members related to AbstractEventTrainer
 
   /**
    * Specifies the tolerance. If the change in training set accuracy
    * is less than this, stop iterating.
    *
-   * @param tolerance
+   * @param tolerance The level of tolerance.
+   *                  Must not be negative.
+   * @throws IllegalArgumentException Thrown if parameters are invalid.
    */
   public void setTolerance(double tolerance) {
 
@@ -171,7 +177,9 @@ public class PerceptronTrainer extends AbstractEventTrainer {
    * Enables and sets step size decrease. The step size is
    * decreased every iteration by the specified value.
    *
-   * @param decrease - step size decrease in percent
+   * @param decrease The step size decrease in percent.
+   *                 Must not be negative.
+   * @throws IllegalArgumentException Thrown if parameters are invalid.
    */
   public void setStepSizeDecrease(double decrease) {
 
@@ -188,7 +196,7 @@ public class PerceptronTrainer extends AbstractEventTrainer {
    * averaging to special averaging instead.
    * <p>
    * If we are doing averaging, and the current iteration is one
-   * of the first 20 or it is a perfect square, then updated the
+   * of the first 20, or if it is a perfect square, then updated the
    * summed parameters.
    * <p>
    * The reason we don't take all of them is that the parameters change
@@ -196,18 +204,38 @@ public class PerceptronTrainer extends AbstractEventTrainer {
    * of the more volatile early iterations. The use of perfect
    * squares allows us to sample from successively farther apart iterations.
    *
-   * @param averaging averaging flag
+   * @param averaging Whether to skip 'averaging', or not.
    */
   public void setSkippedAveraging(boolean averaging) {
     useSkippedlAveraging = averaging;
   }
 
+  /**
+   * Trains a {@link PerceptronModel} with given parameters.
+   * 
+   * @param iterations The number of iterations to use for training.
+   * @param di The {@link DataIndexer} used as data input.
+   * @param cutoff The {{@link #CUTOFF_PARAM}} value to use for training.
+   *               
+   * @return A valid, trained {@link AbstractModel perceptron model}.
+   */
   public AbstractModel trainModel(int iterations, DataIndexer di, int cutoff) {
     return trainModel(iterations,di,cutoff,true);
   }
 
+  /**
+   * Trains a {@link PerceptronModel} with given parameters.
+   *
+   * @param iterations The number of iterations to use for training.
+   * @param di The {@link DataIndexer} used as data input.
+   * @param cutoff The {{@link #CUTOFF_PARAM}} value to use for training.
+   * @param useAverage Whether to use 'averaging', or not.
+   *                   See {{@link #setSkippedAveraging(boolean)}} for details.
+   *
+   * @return A valid, trained {@link AbstractModel perceptron model}.
+   */
   public AbstractModel trainModel(int iterations, DataIndexer di, int cutoff, boolean useAverage) {
-    display("Incorporating indexed data for training...  \n");
+    logger.info("Incorporating indexed data for training... ");
     contexts = di.getContexts();
     values = di.getValues();
     numTimesEventsSeen = di.getNumTimesEventsSeen();
@@ -221,17 +249,17 @@ public class PerceptronTrainer extends AbstractEventTrainer {
     numPreds = predLabels.length;
     numOutcomes = outcomeLabels.length;
 
-    display("done.\n");
+    logger.info("done.");
 
-    display("\tNumber of Event Tokens: " + numUniqueEvents + "\n");
-    display("\t    Number of Outcomes: " + numOutcomes + "\n");
-    display("\t  Number of Predicates: " + numPreds + "\n");
+    logger.info("\tNumber of Event Tokens: {} " +
+        "\n\t Number of Outcomes: {} " +
+        "\n\t Number of Predicates: {}", numUniqueEvents, numOutcomes, numPreds);
 
-    display("Computing model parameters...\n");
+    logger.info("Computing model parameters...");
 
     MutableContext[] finalParameters = findParameters(iterations, useAverage);
 
-    display("...done.\n");
+    logger.info("...done.");
 
     /* Create and return the model *************/
     return new PerceptronModel(finalParameters, predLabels, outcomeLabels);
@@ -239,7 +267,7 @@ public class PerceptronTrainer extends AbstractEventTrainer {
 
   private MutableContext[] findParameters(int iterations, boolean useAverage) {
 
-    display("Performing " + iterations + " iterations.\n");
+    logger.info("Performing {} iterations.", iterations);
 
     int[] allOutcomesPattern = new int[numOutcomes];
     for (int oi = 0; oi < numOutcomes; oi++)
@@ -282,8 +310,6 @@ public class PerceptronTrainer extends AbstractEventTrainer {
       if (stepSizeDecrease != null)
         stepsize *= 1 - stepSizeDecrease;
 
-      displayIteration(i);
-
       int numCorrect = 0;
 
       for (int ei = 0; ei < numUniqueEvents; ei++) {
@@ -326,7 +352,7 @@ public class PerceptronTrainer extends AbstractEventTrainer {
       // Calculate the training accuracy and display.
       double trainingAccuracy = (double) numCorrect / numEvents;
       if (i < 10 || (i % 10) == 0)
-        display(". (" + numCorrect + "/" + numEvents + ") " + trainingAccuracy + "\n");
+        logger.info("{}: ({}/{}) {}", i, numCorrect, numEvents, trainingAccuracy);
 
       // TODO: Make averaging configurable !!!
 
@@ -347,7 +373,7 @@ public class PerceptronTrainer extends AbstractEventTrainer {
       if (StrictMath.abs(prevAccuracy1 - trainingAccuracy) < tolerance
           && StrictMath.abs(prevAccuracy2 - trainingAccuracy) < tolerance
           && StrictMath.abs(prevAccuracy3 - trainingAccuracy) < tolerance) {
-        display("Stopping: change in training set accuracy less than " + tolerance + "\n");
+        logger.warn("Stopping: change in training set accuracy less than {}", tolerance);
         break;
       }
 
@@ -395,24 +421,12 @@ public class PerceptronTrainer extends AbstractEventTrainer {
       }
     }
     double trainingAccuracy = (double) numCorrect / numEvents;
-    display("Stats: (" + numCorrect + "/" + numEvents + ") " + trainingAccuracy + "\n");
+    logger.info("Stats: ({}/{}) {}", numCorrect, numEvents, trainingAccuracy);
     return trainingAccuracy;
   }
 
-  private void displayIteration(int i) {
-    if (i > 10 && (i % 10) != 0)
-      return;
-
-    if (i < 10)
-      display("  " + i + ":  ");
-    else if (i < 100)
-      display(" " + i + ":  ");
-    else
-      display(i + ":  ");
-  }
-
-  // See whether a number is a perfect square. Inefficient, but fine
-  // for our purposes.
+  // See whether a number is a perfect square.
+  // Inefficient, but fine for our purposes.
   private static boolean isPerfectSquare(int n) {
     int root = (int) StrictMath.sqrt(n);
     return root * root == n;
