@@ -23,6 +23,9 @@ import java.util.HashMap;
 import java.util.List;
 import java.util.Map;
 
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
+
 import opennlp.tools.ml.AbstractEventModelSequenceTrainer;
 import opennlp.tools.ml.model.AbstractDataIndexer;
 import opennlp.tools.ml.model.AbstractModel;
@@ -35,41 +38,61 @@ import opennlp.tools.ml.model.SequenceStream;
 import opennlp.tools.ml.model.SequenceStreamEventStream;
 
 /**
- * Trains models for sequences using the perceptron algorithm.  Each outcome is represented as
- * a binary perceptron classifier.  This supports standard (integer) weighting as well
- * average weighting.  Sequence information is used in a simplified was to that described in:
+ * Trains {@link PerceptronModel models} with sequences using the perceptron algorithm.
+ * <p>
+ * Each outcome is represented as a binary perceptron classifier.
+ * This supports standard (integer) weighting as well average weighting.
+ * <p>
+ * Sequence information is used in a simplified was to that described in:
  * Discriminative Training Methods for Hidden Markov Models: Theory and Experiments
  * with the Perceptron Algorithm. Michael Collins, EMNLP 2002.
+ * <p>
  * Specifically only updates are applied to tokens which were incorrectly tagged by a sequence tagger
  * rather than to all feature across the sequence which differ from the training sequence.
+ *
+ * @see PerceptronModel
+ * @see AbstractEventModelSequenceTrainer
  */
 public class SimplePerceptronSequenceTrainer extends AbstractEventModelSequenceTrainer {
 
+  private static final Logger logger = LoggerFactory.getLogger(SimplePerceptronSequenceTrainer.class);
   public static final String PERCEPTRON_SEQUENCE_VALUE = "PERCEPTRON_SEQUENCE";
 
   private int iterations;
-  private SequenceStream sequenceStream;
-  /** Number of events in the event set. */
+  private SequenceStream<Event> sequenceStream;
+  /**
+   * Number of events in the event set.
+   */
   private int numEvents;
 
-  /** Number of predicates. */
+  /**
+   * Number of predicates.
+   */
   private int numPreds;
   private int numOutcomes;
 
-  /** List of outcomes for each event i, in context[i]. */
+  /**
+   * List of outcomes for each event i, in context[i].
+   */
   private int[] outcomeList;
 
   private String[] outcomeLabels;
 
-  /** Stores the average parameter values of each predicate during iteration. */
+  /**
+   * Stores the average parameter values of each predicate during iteration.
+   */
   private MutableContext[] averageParams;
 
-  /** Mapping between context and an integer */
+  /**
+   * Mapping between context and an integer
+   */
   private Map<String, Integer> pmap;
 
-  private Map<String,Integer> omap;
+  private Map<String, Integer> omap;
 
-  /** Stores the estimated parameter value of each predicate during iteration. */
+  /**
+   * Stores the estimated parameter value of each predicate during iteration.
+   */
   private MutableContext[] params;
   private boolean useAverage;
   private int[][][] updates;
@@ -80,9 +103,19 @@ public class SimplePerceptronSequenceTrainer extends AbstractEventModelSequenceT
   private String[] predLabels;
   private int numSequences;
 
+  /**
+   * Instantiates a {@link SimplePerceptronSequenceTrainer} with a default
+   * configuration of training parameters.
+   */
   public SimplePerceptronSequenceTrainer() {
   }
 
+  /**
+   * {@inheritDoc}
+   *
+   * @throws IllegalArgumentException Thrown if the algorithm name is not equal to
+   *                                  {{@link #PERCEPTRON_SEQUENCE_VALUE}}.
+   */
   @Override
   public void validate() {
     super.validate();
@@ -95,19 +128,8 @@ public class SimplePerceptronSequenceTrainer extends AbstractEventModelSequenceT
     }
   }
 
-  @Deprecated
   @Override
-  public boolean isValid() {
-    try {
-      validate();
-      return true;
-    }
-    catch (IllegalArgumentException e) {
-      return false;
-    }
-  }
-
-  public AbstractModel doTrain(SequenceStream events) throws IOException {
+  public AbstractModel doTrain(SequenceStream<Event> events) throws IOException {
     int iterations = getIterations();
     int cutoff = getCutoff();
 
@@ -118,7 +140,16 @@ public class SimplePerceptronSequenceTrainer extends AbstractEventModelSequenceT
 
   // << members related to AbstractSequenceTrainer
 
-  public AbstractModel trainModel(int iterations, SequenceStream sequenceStream,
+  /**
+   * Trains a {@link PerceptronModel} with given parameters.
+   *
+   * @param iterations     The number of iterations to use for training.
+   * @param sequenceStream The {@link SequenceStream<Event>} used as data input.
+   * @param cutoff         The {{@link #CUTOFF_PARAM}} value to use for training.
+   * @param useAverage     Whether to use 'averaging', or not.
+   * @return A valid, trained {@link AbstractModel perceptron model}.
+   */
+  public AbstractModel trainModel(int iterations, SequenceStream<Event> sequenceStream,
                                   int cutoff, boolean useAverage) throws IOException {
     this.iterations = iterations;
     this.sequenceStream = sequenceStream;
@@ -126,7 +157,7 @@ public class SimplePerceptronSequenceTrainer extends AbstractEventModelSequenceT
     trainingParameters.put(AbstractDataIndexer.CUTOFF_PARAM, cutoff);
     trainingParameters.put(AbstractDataIndexer.SORT_PARAM, false);
     DataIndexer di = new OnePassDataIndexer();
-    di.init(trainingParameters,reportMap);
+    di.init(trainingParameters, reportMap);
     di.index(new SequenceStreamEventStream(sequenceStream));
     numSequences = 0;
 
@@ -136,7 +167,7 @@ public class SimplePerceptronSequenceTrainer extends AbstractEventModelSequenceT
       numSequences++;
     }
 
-    outcomeList  = di.getOutcomeList();
+    outcomeList = di.getOutcomeList();
     predLabels = di.getPredLabels();
     pmap = new HashMap<>();
 
@@ -144,7 +175,7 @@ public class SimplePerceptronSequenceTrainer extends AbstractEventModelSequenceT
       pmap.put(predLabels[i], i);
     }
 
-    display("Incorporating indexed data for training...  \n");
+    logger.info("Incorporating indexed data for training... ");
     this.useAverage = useAverage;
     numEvents = di.getNumEvents();
 
@@ -162,15 +193,16 @@ public class SimplePerceptronSequenceTrainer extends AbstractEventModelSequenceT
       updates = new int[numPreds][numOutcomes][3];
     }
 
-    display("done.\n");
-
-    display("\tNumber of Event Tokens: " + numEvents + "\n");
-    display("\t    Number of Outcomes: " + numOutcomes + "\n");
-    display("\t  Number of Predicates: " + numPreds + "\n");
+    logger.info("done.");
 
+    logger.info("\tNumber of Event Tokens: {} " +
+        "\n\t Number of Outcomes: {} " +
+        "\n\t Number of Predicates: {}", numEvents, numOutcomes, numPreds);
 
     params = new MutableContext[numPreds];
-    if (useAverage) averageParams = new MutableContext[numPreds];
+    if (useAverage) {
+      averageParams = new MutableContext[numPreds];
+    }
 
     int[] allOutcomesPattern = new int[numOutcomes];
     for (int oi = 0; oi < numOutcomes; oi++) {
@@ -179,44 +211,39 @@ public class SimplePerceptronSequenceTrainer extends AbstractEventModelSequenceT
 
     for (int pi = 0; pi < numPreds; pi++) {
       params[pi] = new MutableContext(allOutcomesPattern, new double[numOutcomes]);
-      if (useAverage) averageParams[pi] = new MutableContext(allOutcomesPattern,new double[numOutcomes]);
+      if (useAverage) {
+        averageParams[pi] = new MutableContext(allOutcomesPattern, new double[numOutcomes]);
+      }
       for (int aoi = 0; aoi < numOutcomes; aoi++) {
         params[pi].setParameter(aoi, 0.0);
-        if (useAverage) averageParams[pi].setParameter(aoi, 0.0);
+        if (useAverage) {
+          averageParams[pi].setParameter(aoi, 0.0);
+        }
       }
     }
-    double[] modelDistribution = new double[numOutcomes];
 
-    display("Computing model parameters...\n");
+    logger.info("Computing model parameters...");
     findParameters(iterations);
-    display("...done.\n");
+    logger.info("...done.");
 
     /* Create and return the model ****/
     String[] updatedPredLabels = predLabels;
 
     if (useAverage) {
       return new PerceptronModel(averageParams, updatedPredLabels, outcomeLabels);
-    }
-    else {
+    } else {
       return new PerceptronModel(params, updatedPredLabels, outcomeLabels);
     }
   }
 
   private void findParameters(int iterations) throws IOException {
-    display("Performing " + iterations + " iterations.\n");
+    logger.info("Performing {} iterations.\n", iterations);
     for (int i = 1; i <= iterations; i++) {
-      if (i < 10)
-        display("  " + i + ":  ");
-      else if (i < 100)
-        display(" " + i + ":  ");
-      else
-        display(i + ":  ");
       nextIteration(i);
     }
     if (useAverage) {
       trainingStats(averageParams);
-    }
-    else {
+    } else {
       trainingStats(params);
     }
   }
@@ -226,15 +253,15 @@ public class SimplePerceptronSequenceTrainer extends AbstractEventModelSequenceT
     int numCorrect = 0;
     int oei = 0;
     int si = 0;
-    List<Map<String,Float>> featureCounts = new ArrayList<>(numOutcomes);
+    List<Map<String, Float>> featureCounts = new ArrayList<>(numOutcomes);
     for (int oi = 0; oi < numOutcomes; oi++) {
       featureCounts.add(new HashMap<>());
     }
-    PerceptronModel model = new PerceptronModel(params,predLabels,outcomeLabels);
+    PerceptronModel model = new PerceptronModel(params, predLabels, outcomeLabels);
 
     sequenceStream.reset();
 
-    Sequence sequence;
+    Sequence<Event> sequence;
     while ((sequence = sequenceStream.read()) != null) {
       Event[] taggerEvents = sequenceStream.updateContext(sequence, model);
       Event[] events = sequence.getEvents();
@@ -243,8 +270,7 @@ public class SimplePerceptronSequenceTrainer extends AbstractEventModelSequenceT
         if (!taggerEvents[ei].getOutcome().equals(events[ei].getOutcome())) {
           update = true;
           //break;
-        }
-        else {
+        } else {
           numCorrect++;
         }
       }
@@ -252,8 +278,14 @@ public class SimplePerceptronSequenceTrainer extends AbstractEventModelSequenceT
         for (int oi = 0; oi < numOutcomes; oi++) {
           featureCounts.get(oi).clear();
         }
-        //System.err.print("train:");for (int ei=0;ei<events.length;ei++)
-        // {System.err.print(" "+events[ei].getOutcome());} System.err.println();
+        if (logger.isTraceEnabled()) {
+          final StringBuilder sb = new StringBuilder();
+          for (Event event : events) {
+            sb.append(" ").append(event.getOutcome());
+          }
+          logger.trace("train: {}", sb);
+        }
+
         //training feature count computation
         for (int ei = 0; ei < events.length; ei++, oei++) {
           String[] contextStrings = events[ei].getContext();
@@ -267,16 +299,20 @@ public class SimplePerceptronSequenceTrainer extends AbstractEventModelSequenceT
             Float c = featureCounts.get(oi).get(contextStrings[ci]);
             if (c == null) {
               c = value;
-            }
-            else {
+            } else {
               c += value;
             }
             featureCounts.get(oi).put(contextStrings[ci], c);
           }
         }
         //evaluation feature count computation
-        //System.err.print("test: ");for (int ei=0;ei<taggerEvents.length;ei++)
-        // {System.err.print(" "+taggerEvents[ei].getOutcome());} System.err.println();
+        if (logger.isTraceEnabled()) {
+          final StringBuilder sb = new StringBuilder();
+          for (Event taggerEvent : taggerEvents) {
+            sb.append(" ").append(taggerEvent.getOutcome());
+          }
+          logger.trace("test: {}", sb);
+        }
         for (Event taggerEvent : taggerEvents) {
           String[] contextStrings = taggerEvent.getContext();
           float[] values = taggerEvent.getValues();
@@ -289,14 +325,12 @@ public class SimplePerceptronSequenceTrainer extends AbstractEventModelSequenceT
             Float c = featureCounts.get(oi).get(contextStrings[ci]);
             if (c == null) {
               c = -1 * value;
-            }
-            else {
+            } else {
               c -= value;
             }
             if (c == 0f) {
               featureCounts.get(oi).remove(contextStrings[ci]);
-            }
-            else {
+            } else {
               featureCounts.get(oi).put(contextStrings[ci], c);
             }
           }
@@ -305,17 +339,24 @@ public class SimplePerceptronSequenceTrainer extends AbstractEventModelSequenceT
           for (String feature : featureCounts.get(oi).keySet()) {
             int pi = pmap.getOrDefault(feature, -1);
             if (pi != -1) {
-              //System.err.println(si+" "+outcomeLabels[oi]+" "+feature+" "+featureCounts[oi].get(feature));
+              if (logger.isTraceEnabled()) {
+                logger.trace("{} {} {} {}",
+                    si, outcomeLabels[oi], feature, featureCounts.get(oi).get(feature));
+              }
               params[pi].updateParameter(oi, featureCounts.get(oi).get(feature));
               if (useAverage) {
                 if (updates[pi][oi][VALUE] != 0) {
-                  averageParams[pi].updateParameter(oi,updates[pi][oi][VALUE] * (numSequences
+                  averageParams[pi].updateParameter(oi, updates[pi][oi][VALUE] * (numSequences
                       * (iteration - updates[pi][oi][ITER]) + (si - updates[pi][oi][EVENT])));
-                  //System.err.println("p avp["+pi+"]."+oi+"="+averageParams[pi].getParameters()[oi]);
+                  if (logger.isTraceEnabled()) {
+                    logger.trace("p avp[{}].{}={}", pi, oi, averageParams[pi].getParameters()[oi]);
+                  }
+                }
+                if (logger.isTraceEnabled()) {
+                  logger.trace("p updates[{}]{{}]=({},{},{})({},{},{}) -> {}", pi, oi, updates[pi][oi][ITER],
+                      updates[pi][oi][EVENT], updates[pi][oi][VALUE], iteration, oei,
+                      params[pi].getParameters()[oi], averageParams[pi].getParameters()[oi]);
                 }
-                //System.err.println("p updates["+pi+"]["+oi+"]=("+updates[pi][oi][ITER]+","
-                // +updates[pi][oi][EVENT]+","+updates[pi][oi][VALUE]+") + ("+iteration+","+oei+","
-                // +params[pi].getParameters()[oi]+") -> "+averageParams[pi].getParameters()[oi]);
                 updates[pi][oi][VALUE] = (int) params[pi].getParameters()[oi];
                 updates[pi][oi][ITER] = iteration;
                 updates[pi][oi][EVENT] = si;
@@ -323,7 +364,7 @@ public class SimplePerceptronSequenceTrainer extends AbstractEventModelSequenceT
             }
           }
         }
-        model = new PerceptronModel(params,predLabels,outcomeLabels);
+        model = new PerceptronModel(params, predLabels, outcomeLabels);
       }
       si++;
     }
@@ -340,14 +381,17 @@ public class SimplePerceptronSequenceTrainer extends AbstractEventModelSequenceT
           if (predParams[oi] != 0) {
             predParams[oi] /= totIterations;
             averageParams[pi].setParameter(oi, predParams[oi]);
-            //System.err.println("updates["+pi+"]["+oi+"]=("+updates[pi][oi][ITER]+","
-            // +updates[pi][oi][EVENT]+","+updates[pi][oi][VALUE]+") + ("+iterations+","+0+","
-            // +params[pi].getParameters()[oi]+") -> "+averageParams[pi].getParameters()[oi]);
+            if (logger.isTraceEnabled()) {
+              logger.trace("updates[{}][{}]=({},{},{})({},{},{}) -> {}", pi, oi, updates[pi][oi][ITER],
+                  updates[pi][oi][EVENT], updates[pi][oi][VALUE], iterations, 0,
+                  params[pi].getParameters()[oi], averageParams[pi].getParameters()[oi]);
+            }
           }
         }
       }
     }
-    display(". (" + numCorrect + "/" + numEvents + ") " + ((double) numCorrect / numEvents) + "\n");
+    logger.info("{}. ({}/{}) {}", iteration, numCorrect,
+        numEvents, ((double) numCorrect / numEvents));
   }
 
   private void trainingStats(MutableContext[] params) throws IOException {
@@ -356,17 +400,17 @@ public class SimplePerceptronSequenceTrainer extends AbstractEventModelSequenceT
 
     sequenceStream.reset();
 
-    Sequence sequence;
+    Sequence<Event> sequence;
     while ((sequence = sequenceStream.read()) != null) {
       Event[] taggerEvents = sequenceStream.updateContext(sequence,
-          new PerceptronModel(params,predLabels,outcomeLabels));
+          new PerceptronModel(params, predLabels, outcomeLabels));
       for (int ei = 0; ei < taggerEvents.length; ei++, oei++) {
         int max = omap.get(taggerEvents[ei].getOutcome());
         if (max == outcomeList[oei]) {
-          numCorrect ++;
+          numCorrect++;
         }
       }
     }
-    display(". (" + numCorrect + "/" + numEvents + ") " + ((double) numCorrect / numEvents) + "\n");
+    logger.info(". ({}/{}) {}", numCorrect, numEvents, ((double) numCorrect / numEvents));
   }
 }
