@@ -18,7 +18,6 @@
 package opennlp.tools.namefind;
 
 import java.io.IOException;
-import java.io.Serializable;
 import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.Collections;
@@ -27,25 +26,38 @@ import java.util.Objects;
 import java.util.regex.Matcher;
 import java.util.regex.Pattern;
 
+import opennlp.tools.commons.Sample;
 import opennlp.tools.tokenize.WhitespaceTokenizer;
 import opennlp.tools.util.Span;
 
 /**
- * Class for holding names for a single unit of text.
+ * Encapsulates names for a single unit of text.
  */
-public class NameSample implements Serializable {
+public class NameSample implements Sample {
 
+  private static final long serialVersionUID = 1655333056555270688L;
   private final String id;
   private final List<String> sentence;
   private final List<Span> names;
   private final String[][] additionalContext;
   private final boolean isClearAdaptiveData;
 
-  /** The a default type value when there is no type in training data. */
+  /** The default type value when there is no type in training data. */
   public static final String DEFAULT_TYPE = "default";
 
-  public NameSample(String id, String[] sentence, Span[] names,
-      String[][] additionalContext, boolean clearAdaptiveData) {
+  /**
+   * Initializes a {@link NameSample} instance with given parameters.
+   * 
+   * @param id The identifier to use.
+   * @param sentence The tokens representing a training sentence. Must not be {@code null}.
+   * @param names The {@link Span names} to use.
+   * @param additionalContext Additional context in a 2-dimensional array.
+   * @param clearAdaptiveData If {@code true} the adaptive data of the feature generators is cleared.
+   *
+   * @throws RuntimeException Thrown if name spans are overlapping.
+   */
+  public NameSample(String id, String[] sentence, Span[] names, String[][] additionalContext,
+                    boolean clearAdaptiveData) {
     this.id = id;
 
     Objects.requireNonNull(sentence, "sentence must not be null");
@@ -83,41 +95,68 @@ public class NameSample implements Serializable {
       }
     }
   }
-
+  
   /**
-   * Initializes the current instance.
+   * Initializes a {@link NameSample} instance with given parameters.
    *
-   * @param sentence training sentence
-   * @param names
-   * @param additionalContext
-   * @param clearAdaptiveData if true the adaptive data of the
-   *     feature generators is cleared
+   * @param sentence The tokens representing a sentence. Must not be {@code null}.
+   * @param names The {@link Span names} to use.
+   * @param additionalContext Additional context in a 2-dimensional array.
+   * @param clearAdaptiveData If {@code true} the adaptive data of the feature generators is cleared.
+   *
+   * @throws RuntimeException Thrown if name spans are overlapping.
    */
   public NameSample(String[] sentence, Span[] names,
       String[][] additionalContext, boolean clearAdaptiveData) {
     this(null, sentence, names, additionalContext, clearAdaptiveData);
   }
 
+  /**
+   * Initializes a {@link NameSample} instance with given parameters.
+   *
+   * @param sentence The tokens representing a sentence. Must not be {@code null}.
+   * @param names The {@link Span names} to use.
+   * @param clearAdaptiveData If {@code true} the adaptive data of the feature generators is cleared.
+   *
+   * @throws RuntimeException Thrown if name spans are overlapping.
+   */
   public NameSample(String[] sentence, Span[] names, boolean clearAdaptiveData) {
     this(sentence, names, null, clearAdaptiveData);
   }
 
+  /**
+   * @return Retrieves the current identifier. May be {@code null}.
+   */
   public String getId() {
     return id;
   }
 
+  /**
+   * @return Retrieves the sentence in tokenized form.
+   */
   public String[] getSentence() {
-    return sentence.toArray(new String[sentence.size()]);
+    return sentence.toArray(new String[0]);
   }
 
+  /**
+   * @return Retrieves the {@link Span names}.
+   */
   public Span[] getNames() {
-    return names.toArray(new Span[names.size()]);
+    return names.toArray(new Span[0]);
   }
 
+
+  /**
+   * @return Retrieves additional context. May be {@code null}.
+   */
   public String[][] getAdditionalContext() {
     return additionalContext;
   }
 
+  /**
+   * @return {@code true} if the adaptive data of the feature generators are cleared,
+   *         {@code false} otherwise.
+   */
   public boolean isClearAdaptiveDataSet() {
     return isClearAdaptiveData;
   }
@@ -135,8 +174,7 @@ public class NameSample implements Serializable {
       return true;
     }
 
-    if (obj instanceof NameSample) {
-      NameSample a = (NameSample) obj;
+    if (obj instanceof NameSample a) {
 
       return Arrays.equals(getSentence(), a.getSentence()) &&
           Arrays.equals(getNames(), a.getNames()) &&
@@ -218,14 +256,33 @@ public class NameSample implements Serializable {
 
   private static final Pattern START_TAG_PATTERN = Pattern.compile("<START(:([^:>\\s]*))?>");
 
-  public static NameSample parse(String taggedTokens,
-      boolean isClearAdaptiveData) throws IOException {
-    return parse(taggedTokens, DEFAULT_TYPE, isClearAdaptiveData);
+
+  /**
+   * Parses given input into a {@link NameSample}.
+   * 
+   * @param taggedTokens The input data to parse.
+   * @param clearAdaptiveData {@code true} if the adaptive data of the feature generators should be cleared,
+   *                          {@code false} otherwise.
+   * @return A {@link NameSample} instance resulting from the parsing.
+   * @throws IOException Thrown if IO errors occurred during parsing.
+   */
+  public static NameSample parse(String taggedTokens, boolean clearAdaptiveData) throws IOException {
+    return parse(taggedTokens, DEFAULT_TYPE, clearAdaptiveData);
   }
 
-  public static NameSample parse(String taggedTokens, String defaultType,
-      boolean isClearAdaptiveData) throws IOException {
-    // TODO: Should throw another exception, and then convert it into an IOException in the stream
+  /**
+   * Parses given input into a {@link NameSample}.
+   *
+   * @param taggedTokens The input data to parse.
+   * @param defaultType The type to set by default.
+   * @param clearAdaptiveData {@code true} if the adaptive data of the feature generators should be cleared,
+   *                          {@code false} otherwise.
+   * @return A {@link NameSample} instance resulting from the parsing.
+   * @throws IOException Thrown if IO errors occurred during parsing.
+   */
+  // TODO: Should throw another exception, and then convert it into an IOException in the stream
+  public static NameSample parse(String taggedTokens, String defaultType, boolean clearAdaptiveData)
+          throws IOException {
 
     String[] parts = WhitespaceTokenizer.INSTANCE.tokenize(taggedTokens);
 
@@ -272,9 +329,9 @@ public class NameSample implements Serializable {
         wordIndex++;
       }
     }
-    String[] sentence = tokenList.toArray(new String[tokenList.size()]);
-    Span[] names = nameList.toArray(new Span[nameList.size()]);
+    String[] sentence = tokenList.toArray(new String[0]);
+    Span[] names = nameList.toArray(new Span[0]);
 
-    return new NameSample(sentence, names, isClearAdaptiveData);
+    return new NameSample(sentence, names, clearAdaptiveData);
   }
 }
