@@ -20,6 +20,7 @@ package opennlp.tools.ngram;
 import java.io.IOException;
 import java.io.InputStream;
 import java.io.OutputStream;
+import java.nio.CharBuffer;
 import java.util.Iterator;
 import java.util.LinkedHashMap;
 import java.util.Map;
@@ -42,7 +43,7 @@ public class NGramModel implements Iterable<StringList> {
 
   protected static final String COUNT = "count";
 
-  private Map<StringList, Integer> mNGrams = new LinkedHashMap<>();
+  private final Map<StringList, Integer> mNGrams = new LinkedHashMap<>();
 
   /**
    * Initializes an empty instance.
@@ -63,7 +64,7 @@ public class NGramModel implements Iterable<StringList> {
       String countValueString = null;
 
       try {
-        countValueString = entry.getAttributes().getValue(COUNT);
+        countValueString = entry.attributes().getValue(COUNT);
 
         if (countValueString == null) {
           throw new InvalidFormatException(
@@ -76,8 +77,8 @@ public class NGramModel implements Iterable<StringList> {
             + "' must be a number!", e);
       }
 
-      add(entry.getTokens());
-      setCount(entry.getTokens(), count);
+      add(entry.tokens());
+      setCount(entry.tokens(), count);
     });
   }
 
@@ -169,15 +170,11 @@ public class NGramModel implements Iterable<StringList> {
    * @param maxLength
    */
   public void add(CharSequence chars, int minLength, int maxLength) {
-
+    CharBuffer cb = StringUtil.toLowerCaseCharBuffer(chars);
     for (int lengthIndex = minLength; lengthIndex < maxLength + 1; lengthIndex++) {
-      for (int textIndex = 0;
-          textIndex + lengthIndex - 1 < chars.length(); textIndex++) {
-
-        String gram = StringUtil.toLowerCase(
-            chars.subSequence(textIndex, textIndex + lengthIndex));
-
-        add(new StringList(new String[]{gram}));
+      for (int textIndex = 0; textIndex + lengthIndex - 1 < chars.length(); textIndex++) {
+        CharSequence gram = cb.subSequence(textIndex, textIndex + lengthIndex);
+        add(new StringList(new String[]{gram.toString()}));
       }
     }
   }
@@ -264,9 +261,9 @@ public class NGramModel implements Iterable<StringList> {
   /**
    * Creates a dictionary which contain all {@link StringList} which
    * are in the current {@link NGramModel}.
-   *
+   * <p>
    * Entries which are only different in the case are merged into one.
-   *
+   * <p>
    * Calling this method is the same as calling {@link #toDictionary(boolean)} with true.
    *
    * @return a dictionary of the ngrams
@@ -303,9 +300,8 @@ public class NGramModel implements Iterable<StringList> {
    * @throws IOException if an I/O Error during writing occurs
    */
   public void serialize(OutputStream out) throws IOException {
-    Iterator<Entry> entryIterator = new Iterator<Entry>()
-    {
-      private Iterator<StringList> mDictionaryIterator = NGramModel.this.iterator();
+    Iterator<Entry> entryIterator = new Iterator<>() {
+      private final Iterator<StringList> mDictionaryIterator = NGramModel.this.iterator();
 
       @Override
       public boolean hasNext() {
@@ -316,11 +312,9 @@ public class NGramModel implements Iterable<StringList> {
       public Entry next() {
 
         StringList tokens = mDictionaryIterator.next();
-
         Attributes attributes = new Attributes();
-
         attributes.setValue(COUNT, Integer.toString(getCount(tokens)));
-        
+
         return new Entry(tokens, attributes);
       }
 
@@ -341,8 +335,7 @@ public class NGramModel implements Iterable<StringList> {
     if (obj == this) {
       result = true;
     }
-    else if (obj instanceof NGramModel) {
-      NGramModel model  = (NGramModel) obj;
+    else if (obj instanceof NGramModel model) {
 
       result = mNGrams.equals(model.mNGrams);
     }
