@@ -48,15 +48,15 @@ import opennlp.tools.util.model.SerializableArtifact;
  * Class for storing the Ancora Spanish head rules associated with parsing. In this class
  * headrules for noun phrases are specified. The rest of the rules are
  * in opennlp-tools/lang/es/parser/es-head-rules
- *
+ * <p>
  * NOTE: This class has been adapted from opennlp.tools.parser.lang.en.HeadRules
- *
+ * <p>
  * The main change is the constituents search direction in the first for loop.
- *
+ * <p>
  * Note also the change in the return of the getHead() method:
  * In the lang.en.HeadRules class: return constituents[ci].getHead();
  * Now: return constituents[ci];
- *
+ * <p>
  * Other changes include removal of deprecated methods.
  *
  */
@@ -100,8 +100,7 @@ public class AncoraSpanishHeadRules implements HeadRules, GapLabeler, Serializab
         return true;
       }
 
-      if (obj instanceof HeadRule) {
-        HeadRule rule = (HeadRule) obj;
+      if (obj instanceof HeadRule rule) {
 
         return (rule.leftToRight == leftToRight) &&
             Arrays.equals(rule.tags, tags);
@@ -112,16 +111,14 @@ public class AncoraSpanishHeadRules implements HeadRules, GapLabeler, Serializab
   }
 
   private Map<String, HeadRule> headRules;
-  private Set<String> punctSet;
-
-
+  private final Set<String> punctSet;
 
   /**
    * Creates a new set of head rules based on the specified reader.
    *
-   * @param rulesReader the head rules reader.
+   * @param rulesReader A {@link Reader} for a head rules file.
    *
-   * @throws IOException if the head rules reader can not be read.
+   * @throws IOException Thrown  f the head rules reader can not be read.
    */
   public AncoraSpanishHeadRules(Reader rulesReader) throws IOException {
     BufferedReader in = new BufferedReader(rulesReader);
@@ -135,10 +132,12 @@ public class AncoraSpanishHeadRules implements HeadRules, GapLabeler, Serializab
     //punctSet.add(":");
   }
 
+  @Override
   public Set<String> getPunctuationTags() {
     return punctSet;
   }
 
+  @Override
   public Parse getHead(Parse[] constituents, String type) {
     if (Parser.TOK_NODE.equals(constituents[0].getType())) {
       return null;
@@ -154,9 +153,9 @@ public class AncoraSpanishHeadRules implements HeadRules, GapLabeler, Serializab
           }
         }
       }
-      for (int ci = 0; ci < constituents.length; ci++) {
-        if (constituents[ci].getType().equals("SN") || constituents[ci].getType().equals("GRUP.NOM")) {
-          return constituents[ci];
+      for (Parse constituent : constituents) {
+        if (constituent.getType().equals("SN") || constituent.getType().equals("GRUP.NOM")) {
+          return constituent;
         }
       }
       String[] tags2 = {"\\$","GRUP\\.A","SA"};
@@ -182,19 +181,19 @@ public class AncoraSpanishHeadRules implements HeadRules, GapLabeler, Serializab
       int cl = constituents.length;
       int tl = tags.length;
       if (hr.leftToRight) {
-        for (int ti = 0; ti < tl; ti++) {
-          for (int ci = 0; ci < cl; ci++) {
-            if (constituents[ci].getType().matches(tags[ti])) {
-              return constituents[ci];
+        for (String tag : tags) {
+          for (Parse constituent : constituents) {
+            if (constituent.getType().matches(tag)) {
+              return constituent;
             }
           }
         }
         return constituents[0].getHead();
       }
       else {
-        for (int ti = 0; ti < tl; ti++) {
+        for (String tag : tags) {
           for (int ci = cl - 1; ci >= 0; ci--) {
-            if (constituents[ci].getType().matches(tags[ti])) {
+            if (constituents[ci].getType().matches(tag)) {
               return constituents[ci];
             }
           }
@@ -223,6 +222,7 @@ public class AncoraSpanishHeadRules implements HeadRules, GapLabeler, Serializab
     }
   }
 
+  @Override
   public void labelGaps(Stack<Constituent> stack) {
     if (stack.size() > 4) {
       //Constituent con0 = (Constituent) stack.get(stack.size()-1);
@@ -250,15 +250,17 @@ public class AncoraSpanishHeadRules implements HeadRules, GapLabeler, Serializab
   }
 
   /**
-   * Writes the head rules to the writer in a format suitable for loading
-   * the head rules again with the constructor. The encoding must be
-   * taken into account while working with the writer and reader.
+   * Serializes the head rules via a {@link Writer} in a format suitable for loading
+   * the head rules again. The encoding must be taken into account while
+   * working with the writer and reader.
    * <p>
-   * After the entries have been written, the writer is flushed.
-   * The writer remains open after this method returns.
+   * Once the entries have been written, the {@code writer} is flushed.
+   * <p>
+   * Note:
+   * The {@code writer} remains open after this method returns.
    *
-   * @param writer
-   * @throws IOException
+   * @param writer The {@link Writer} to write the head rules to.
+   * @throws IOException Thrown if IO errors occurred during write operation.
    */
   public void serialize(Writer writer) throws IOException {
 
@@ -303,8 +305,7 @@ public class AncoraSpanishHeadRules implements HeadRules, GapLabeler, Serializab
       return true;
     }
 
-    if (obj instanceof AncoraSpanishHeadRules) {
-      AncoraSpanishHeadRules rules = (AncoraSpanishHeadRules) obj;
+    if (obj instanceof AncoraSpanishHeadRules rules) {
 
       return rules.headRules.equals(headRules)
           && rules.punctSet.equals(punctSet);
