@@ -25,6 +25,9 @@ import java.util.Map;
 import java.util.Map.Entry;
 import java.util.concurrent.atomic.AtomicInteger;
 
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
+
 import opennlp.tools.dictionary.Dictionary;
 import opennlp.tools.ml.BeamSearch;
 import opennlp.tools.ml.EventModelSequenceTrainer;
@@ -45,17 +48,20 @@ import opennlp.tools.util.StringUtil;
 import opennlp.tools.util.TrainingParameters;
 import opennlp.tools.util.featuregen.StringPattern;
 
+
 /**
- * A part-of-speech tagger that uses maximum entropy.  Tries to predict whether
- * words are nouns, verbs, or any of 70 other POS tags depending on their
- * surrounding context.
- *
+ * A {@link POSTagger part-of-speech tagger} that uses maximum entropy.
+ * <p>
+ * Tries to predict whether words are nouns, verbs, or any of 70 other POS tags
+ * depending on their surrounding context.
  */
 public class POSTaggerME implements POSTagger {
 
+  private static final Logger logger = LoggerFactory.getLogger(POSTaggerME.class);
+
   public static final int DEFAULT_BEAM_SIZE = 3;
 
-  private POSModel modelPackage;
+  private final POSModel modelPackage;
 
   /**
    * The feature context generator.
@@ -63,18 +69,17 @@ public class POSTaggerME implements POSTagger {
   protected POSContextGenerator contextGen;
 
   /**
-   * Tag dictionary used for restricting words to a fixed set of tags.
+   * {@link TagDictionary} used for restricting words to a fixed set of tags.
    */
   protected TagDictionary tagDictionary;
 
-  protected Dictionary ngramDictionary;
+  protected Dictionary ngramDictionary; // TODO unused - Could this be removed?
 
   /**
    * Says whether a filter should be used to check whether a tag assignment
-   * is to a word outside of a closed class.
+   * is to a word outside a closed class.
    */
-  protected boolean useClosedClassTagsFilter = false;
-
+  protected boolean useClosedClassTagsFilter = false; // TODO unused - Could this be removed?
 
   /**
    * The size of the beam to be used in determining the best sequence of pos tags.
@@ -83,23 +88,26 @@ public class POSTaggerME implements POSTagger {
 
   private Sequence bestSequence;
 
-  private SequenceClassificationModel<String> model;
+  private final SequenceClassificationModel<String> model;
 
-  private SequenceValidator<String> sequenceValidator;
+  private final SequenceValidator<String> sequenceValidator;
 
   /**
-   * Initializes the sentence detector by downloading a default model.
-   * @param language The language of the POS tagger
-   * @throws IOException Thrown if the model cannot be downloaded or saved.
+   * Initializes a {@link POSTaggerME} by downloading a default model for a given
+   * {@code language}.
+   *
+   * @param language An ISO conform language code.
+   *                 
+   * @throws IOException Thrown if the model could not be downloaded or saved.
    */
   public POSTaggerME(String language) throws IOException {
-    this((POSModel) DownloadUtil.downloadModel(language, DownloadUtil.ModelType.POS, POSModel.class));
+    this(DownloadUtil.downloadModel(language, DownloadUtil.ModelType.POS, POSModel.class));
   }
 
   /**
-   * Initializes the current instance with the provided model.
+   * Initializes a {@link POSTaggerME} with the provided {@link POSModel model}.
    *
-   * @param model
+   * @param model A valid {@link POSModel}.
    */
   public POSTaggerME(POSModel model) {
     POSTaggerFactory factory = model.getFactory();
@@ -131,32 +139,31 @@ public class POSTaggerME implements POSTagger {
   }
 
   /**
-   * Retrieves an array of all possible part-of-speech tags from the
-   * tagger.
-   *
-   * @return String[]
+   * @return Retrieves an array of all possible part-of-speech tags from the tagger.
    */
   public String[] getAllPosTags() {
     return model.getOutcomes();
   }
 
+  @Override
   public String[] tag(String[] sentence) {
     return this.tag(sentence, null);
   }
 
-  public String[] tag(String[] sentence, Object[] additionaContext) {
-    bestSequence = model.bestSequence(sentence, additionaContext, contextGen, sequenceValidator);
+  @Override
+  public String[] tag(String[] sentence, Object[] additionalContext) {
+    bestSequence = model.bestSequence(sentence, additionalContext, contextGen, sequenceValidator);
     List<String> t = bestSequence.getOutcomes();
-    return t.toArray(new String[t.size()]);
+    return t.toArray(new String[0]);
   }
 
   /**
-   * Returns at most the specified number of taggings for the specified sentence.
+   * Returns at most the specified {@code numTaggings} for the specified {@code sentence}.
    *
    * @param numTaggings The number of tagging to be returned.
    * @param sentence An array of tokens which make up a sentence.
    *
-   * @return At most the specified number of taggings for the specified sentence.
+   * @return At most the specified number of taggings for the specified {@code sentence}.
    */
   public String[][] tag(int numTaggings, String[] sentence) {
     Sequence[] bestSequences = model.bestSequences(numTaggings, sentence, null,
@@ -164,17 +171,19 @@ public class POSTaggerME implements POSTagger {
     String[][] tags = new String[bestSequences.length][];
     for (int si = 0; si < tags.length; si++) {
       List<String> t = bestSequences[si].getOutcomes();
-      tags[si] = t.toArray(new String[t.size()]);
+      tags[si] = t.toArray(new String[0]);
     }
     return tags;
   }
 
+  @Override
   public Sequence[] topKSequences(String[] sentence) {
     return this.topKSequences(sentence, null);
   }
 
-  public Sequence[] topKSequences(String[] sentence, Object[] additionaContext) {
-    return model.bestSequences(size, sentence, additionaContext, contextGen, sequenceValidator);
+  @Override
+  public Sequence[] topKSequences(String[] sentence, Object[] additionalContext) {
+    return model.bestSequences(size, sentence, additionalContext, contextGen, sequenceValidator);
   }
 
   /**
@@ -187,9 +196,7 @@ public class POSTaggerME implements POSTagger {
   }
 
   /**
-   * Returns an array with the probabilities for each tag of the last tagged sentence.
-   *
-   * @return an array with the probabilities for each tag of the last tagged sentence.
+   * @return An array with the probabilities for each tag of the last tagged sentence.
    */
   public double[] probs() {
     return bestSequence.getProbs();
@@ -206,8 +213,8 @@ public class POSTaggerME implements POSTagger {
       MaxentModel posModel = modelPackage.getPosModel();
 
       double[] probs = posModel.eval(contextGen.getContext(index,
-          words.toArray(new String[words.size()]),
-          tags.toArray(new String[tags.size()]),null));
+          words.toArray(new String[0]),
+          tags.toArray(new String[0]),null));
 
       String[] orderedTags = new String[probs.length];
       for (int i = 0; i < probs.length; i++) {
@@ -227,7 +234,7 @@ public class POSTaggerME implements POSTagger {
     }
     else {
       throw new UnsupportedOperationException("This method can only be called if the "
-          + "classifcation model is an event model!");
+          + "classification model is an event model!");
     }
   }
 
@@ -254,7 +261,7 @@ public class POSTaggerME implements POSTagger {
     }
     else if (TrainerType.EVENT_MODEL_SEQUENCE_TRAINER.equals(trainerType)) {
       POSSampleSequenceStream ss = new POSSampleSequenceStream(samples, contextGenerator);
-      EventModelSequenceTrainer trainer =
+      EventModelSequenceTrainer<POSSample> trainer =
           TrainerFactory.getEventModelSequenceTrainer(trainParams, manifestInfoEntries);
       posModel = trainer.train(ss);
     }
@@ -279,11 +286,20 @@ public class POSTaggerME implements POSTagger {
     }
   }
 
+  /**
+   * Constructs a {@link Dictionary nGram dictionary} from an {@link ObjectStream} of samples.
+   *
+   * @param samples The {@link ObjectStream} to process.
+   * @param cutoff  A non-negative cut-off value.
+   *
+   * @return A valid {@link Dictionary} instance holding nGrams.
+   *
+   * @throws IOException Thrown if IO errors occurred during dictionary construction.
+   */
   public static Dictionary buildNGramDictionary(ObjectStream<POSSample> samples, int cutoff)
       throws IOException {
 
     NGramModel ngramModel = new NGramModel();
-
     POSSample sample;
     while ((sample = samples.read()) != null) {
       String[] words = sample.getSentence();
@@ -297,9 +313,19 @@ public class POSTaggerME implements POSTagger {
     return ngramModel.toDictionary(true);
   }
 
+  /**
+   * Populates a {@link POSDictionary} from an {@link ObjectStream} of samples.
+   *
+   * @param samples The {@link ObjectStream} to process.
+   * @param dict The {@link MutableTagDictionary} to use during population.
+   * @param cutoff  A non-negative cut-off value.
+   *
+   * @throws IOException Thrown if IO errors occurred during dictionary construction.
+   */
   public static void populatePOSDictionary(ObjectStream<POSSample> samples,
       MutableTagDictionary dict, int cutoff) throws IOException {
-    System.out.println("Expanding POS Dictionary ...");
+
+    logger.info("Expanding POS Dictionary ...");
     long start = System.nanoTime();
 
     // the data structure will store the word, the tag, and the number of
@@ -356,11 +382,10 @@ public class POSTaggerME implements POSTagger {
       }
       if (tagsForWord.size() > 0) {
         dict.put(wordEntry.getKey(),
-            tagsForWord.toArray(new String[tagsForWord.size()]));
+            tagsForWord.toArray(new String[0]));
       }
     }
 
-    System.out.println("... finished expanding POS Dictionary. ["
-        + (System.nanoTime() - start) / 1000000 + "ms]");
+    logger.info("... finished expanding POS Dictionary. [ {} ms]", (System.nanoTime() - start) / 1000000 );
   }
 }
