@@ -35,25 +35,26 @@ import opennlp.tools.tokenize.lang.Factory;
 import opennlp.tools.util.DownloadUtil;
 import opennlp.tools.util.ObjectStream;
 import opennlp.tools.util.Span;
+import opennlp.tools.util.StringList;
 import opennlp.tools.util.TrainingParameters;
 
 /**
- * A Tokenizer for converting raw text into separated tokens.  It uses
- * Maximum Entropy to make its decisions.  The features are loosely
+ * A {@link Tokenizer} for converting raw text into separated tokens. It uses
+ * Maximum Entropy to make its decisions. The features are loosely
  * based off of Jeff Reynar's UPenn thesis "Topic Segmentation:
  * Algorithms and Applications.", which is available from his
  * homepage: <a href="http://www.cis.upenn.edu/~jcreynar">http://www.cis.upenn.edu/~jcreynar</a>.
  * <p>
- * This tokenizer needs a statistical model to tokenize a text which reproduces
+ * This implementation needs a statistical model to tokenize a text which reproduces
  * the tokenization observed in the training data used to create the model.
- * The {@link TokenizerModel} class encapsulates the model and provides
+ * The {@link TokenizerModel} class encapsulates that model and provides
  * methods to create it from the binary representation.
  * <p>
- * A tokenizer instance is not thread safe. For each thread one tokenizer
- * must be instantiated which can share one <code>TokenizerModel</code> instance
+ * A tokenizer instance is not thread-safe. For each thread, one tokenizer
+ * must be instantiated which can share one {@link TokenizerModel} instance
  * to safe memory.
  * <p>
- * To train a new model {{@link #train(ObjectStream, TokenizerFactory, TrainingParameters)} method
+ * To train a new model, the {@link #train(ObjectStream, TokenizerFactory, TrainingParameters)} method
  * can be used.
  * <p>
  * Sample usage:
@@ -69,7 +70,6 @@ import opennlp.tools.util.TrainingParameters;
  * <br>
  * String tokens[] = tokenizer.tokenize("A sentence to be tokenized.");
  * </code>
- *
  * @see Tokenizer
  * @see TokenizerModel
  * @see TokenSample
@@ -86,56 +86,59 @@ public class TokenizerME extends AbstractTokenizer {
    */
   public static final String NO_SPLIT = "F";
 
-  /**
-   * Alpha-Numeric Pattern
-   * @deprecated As of release 1.5.2, replaced by {@link Factory#getAlphanumeric(String)}
-   */
-  @Deprecated
-  public static final Pattern alphaNumeric = Pattern.compile(Factory.DEFAULT_ALPHANUMERIC);
-
   private final Pattern alphanumeric;
 
-  /**
+  /*
    * The maximum entropy model to use to evaluate contexts.
    */
-  private MaxentModel model;
+  private final MaxentModel model;
 
-  /**
+  /*
    * The context generator.
    */
   private final TokenContextGenerator cg;
 
-  /**
-   * Optimization flag to skip alpha numeric tokens for further
-   * tokenization
+  /*
+   * Optimization flag to skip alphanumeric tokens for further tokenization
    */
-  private boolean useAlphaNumericOptimization;
+  private final boolean useAlphaNumericOptimization;
 
-  /**
+  /*
    * List of probabilities for each token returned from a call to
    * <code>tokenize</code> or <code>tokenizePos</code>.
    */
-  private List<Double> tokProbs;
+  private final List<Double> tokProbs;
 
-  private List<Span> newTokens;
+  private final List<Span> newTokens;
+
+  /*
+   * The {@link Dictionary abbreviation dictionary} if available (may be {@code null}).
+   */
+  private final Dictionary abbDict;
 
   /**
-   * Initializes the tokenizer by downloading a default model.
+   * Initializes a {@link TokenizerME} by downloading a default model.
    * @param language The language of the tokenizer.
    * @throws IOException Thrown if the model cannot be downloaded or saved.
    */
   public TokenizerME(String language) throws IOException {
-    this((TokenizerModel) DownloadUtil.downloadModel(language, DownloadUtil.ModelType.TOKENIZER,
+    this(DownloadUtil.downloadModel(language, DownloadUtil.ModelType.TOKENIZER,
             TokenizerModel.class));
   }
 
+  /**
+   * Instantiates a {@link TokenizerME} with an existing {@link TokenizerModel}.
+   *
+   * @param model The {@link TokenizerModel} to be used.
+   */
   public TokenizerME(TokenizerModel model) {
     TokenizerFactory factory = model.getFactory();
     this.alphanumeric = factory.getAlphaNumericPattern();
     this.cg = factory.getContextGenerator();
     this.model = model.getMaxentModel();
-    this.useAlphaNumericOptimization = factory.isUseAlphaNumericOptmization();
+    this.useAlphaNumericOptimization = factory.isUseAlphaNumericOptimization();
 
+    abbDict = model.getAbbreviations();
     newTokens = new ArrayList<>();
     tokProbs = new ArrayList<>(50);
   }
@@ -144,6 +147,7 @@ public class TokenizerME extends AbstractTokenizer {
    * @deprecated use {@link TokenizerFactory} to extend the Tokenizer
    *             functionality
    */
+  @Deprecated
   public TokenizerME(TokenizerModel model, Factory factory) {
     String languageCode = model.getLanguage();
 
@@ -154,6 +158,7 @@ public class TokenizerME extends AbstractTokenizer {
     this.model = model.getMaxentModel();
     useAlphaNumericOptimization = model.useAlphaNumericOptimization();
 
+    abbDict = model.getAbbreviations();
     newTokens = new ArrayList<>();
     tokProbs = new ArrayList<>(50);
   }
@@ -166,11 +171,9 @@ public class TokenizerME extends AbstractTokenizer {
   }
 
   /**
-   * Returns the probabilities associated with the most recent
-   * calls to {@link TokenizerME#tokenize(String)} or {@link TokenizerME#tokenizePos(String)}.
-   *
-   * @return probability for each token returned for the most recent
-   *     call to tokenize.  If not applicable an empty array is returned.
+   * @return the probabilities associated with the most recent calls to
+   *         {@link TokenizerME#tokenize(String)} or {@link TokenizerME#tokenizePos(String)}.
+   *         If not applicable an empty array is returned.
    */
   public double[] getTokenProbabilities() {
     double[] tokProbArray = new double[tokProbs.size()];
@@ -185,8 +188,9 @@ public class TokenizerME extends AbstractTokenizer {
    *
    * @param d  The string to be tokenized.
    *
-   * @return   A span array containing individual tokens as elements.
+   * @return   A {@link Span} array containing individual tokens as elements.
    */
+  @Override
   public Span[] tokenizePos(String d) {
     WhitespaceTokenizer whitespaceTokenizer = WhitespaceTokenizer.INSTANCE;
     whitespaceTokenizer.setKeepNewLines(keepNewLines);
@@ -213,14 +217,22 @@ public class TokenizerME extends AbstractTokenizer {
           String best = model.getBestOutcome(probs);
           tokenProb *= probs[model.getIndex(best)];
           if (best.equals(TokenizerME.SPLIT)) {
-            newTokens.add(new Span(start, j));
-            tokProbs.add(tokenProb);
-            start = j;
+            if (isAcceptableAbbreviation(tok)) {
+              newTokens.add(new Span(start, end));
+              tokProbs.add(tokenProb);
+              start = j + 1; // To compensate for the abbreviation dot
+            } else {
+              newTokens.add(new Span(start, j));
+              tokProbs.add(tokenProb);
+              start = j;
+            }
             tokenProb = 1.0;
           }
         }
-        newTokens.add(new Span(start, end));
-        tokProbs.add(tokenProb);
+        if (start < end) {
+          newTokens.add(new Span(start, end));
+          tokProbs.add(tokenProb);
+        }
       }
     }
 
@@ -232,18 +244,12 @@ public class TokenizerME extends AbstractTokenizer {
   /**
    * Trains a model for the {@link TokenizerME}.
    *
-   * @param samples
-   *          the samples used for the training.
-   * @param factory
-   *          a {@link TokenizerFactory} to get resources from
-   * @param mlParams
-   *          the machine learning train parameters
-   * @return the trained {@link TokenizerModel}
-   * @throws IOException
-   *           it throws an {@link IOException} if an {@link IOException} is
-   *           thrown during IO operations on a temp file which is created
-   *           during training. Or if reading from the {@link ObjectStream}
-   *           fails.
+   * @param samples The samples used for the training.
+   * @param factory A {@link TokenizerFactory} to get resources from.
+   * @param mlParams The machine learning {@link TrainingParameters train parameters}.
+   * @return A trained {@link TokenizerModel}.
+   * @throws IOException Thrown during IO operations on a temp file which is created
+   *           during training. Or if reading from the {@link ObjectStream} fails.
    */
   public static TokenizerModel train(ObjectStream<TokenSample> samples, TokenizerFactory factory,
       TrainingParameters mlParams) throws IOException {
@@ -251,7 +257,7 @@ public class TokenizerME extends AbstractTokenizer {
     Map<String, String> manifestInfoEntries = new HashMap<>();
 
     ObjectStream<Event> eventStream = new TokSpanEventStream(samples,
-        factory.isUseAlphaNumericOptmization(),
+        factory.isUseAlphaNumericOptimization(),
         factory.getAlphaNumericPattern(), factory.getContextGenerator());
 
     EventTrainer trainer = TrainerFactory.getEventTrainer(
@@ -263,12 +269,25 @@ public class TokenizerME extends AbstractTokenizer {
   }
 
   /**
-   * Returns the value of the alpha-numeric optimization flag.
-   *
-   * @return true if the tokenizer should use alpha-numeric optimization, false otherwise.
+   * @return {@code true} if the tokenizer uses alphanumeric optimization, {@code false} otherwise.
    */
   public boolean useAlphaNumericOptimization() {
     return useAlphaNumericOptimization;
   }
 
+  /**
+   * Allows checking a token abbreviation candidate for acceptability.
+   *
+   * <p>Note: The implementation always returns {@code false} if no
+   * abbreviation dictionary is available for the underlying model.</p>
+   *
+   * @param s the {@link CharSequence token} to check for.
+   * @return {@code true} if the candidate is acceptable, {@code false} otherwise.
+   */
+  protected boolean isAcceptableAbbreviation(CharSequence s) {
+    if (abbDict == null)
+      return false;
+
+    return abbDict.contains(new StringList(s.toString()));
+  }
 }
