@@ -22,6 +22,7 @@ import java.io.IOException;
 
 import org.junit.jupiter.api.Assertions;
 import org.junit.jupiter.api.Test;
+import org.junit.jupiter.api.io.TempDir;
 
 import opennlp.tools.util.InvalidFormatException;
 
@@ -31,17 +32,19 @@ import opennlp.tools.util.InvalidFormatException;
 
 public class LeipzigLanguageSampleStreamTest {
 
-  private static String testDataPath = LeipzigLanguageSampleStreamTest.class
+  private static final String testDataPath = LeipzigLanguageSampleStreamTest.class
       .getClassLoader().getResource("opennlp/tools/formats/leipzig/samples").getPath();
 
+  @TempDir
+  File emptyTempDir;
+
   @Test
   void testReadSentenceFiles() {
-
     int samplesPerLanguage = 2;
     int sentencesPerSample = 1;
-    try {
-      LeipzigLanguageSampleStream stream = new LeipzigLanguageSampleStream(new File(testDataPath),
-          sentencesPerSample, samplesPerLanguage);
+    try (LeipzigLanguageSampleStream stream = new LeipzigLanguageSampleStream(new File(testDataPath),
+            sentencesPerSample, samplesPerLanguage)) {
+      
       int count = 0;
       while (stream.read() != null) {
         count++;
@@ -60,14 +63,30 @@ public class LeipzigLanguageSampleStreamTest {
       int samplesPerLanguage = 2;
       int sentencesPerSample = 2;
 
-      LeipzigLanguageSampleStream stream =
-          new LeipzigLanguageSampleStream(new File(testDataPath),
-              sentencesPerSample, samplesPerLanguage);
-      while (stream.read() != null) ;
+      try (LeipzigLanguageSampleStream stream = new LeipzigLanguageSampleStream(
+              new File(testDataPath), sentencesPerSample, samplesPerLanguage)) {
+
+        while (stream.read() != null) ;
+      }
 
     });
+  }
 
+  @Test
+  void testReadSentenceFilesWithEmptyDir() {
+    int samplesPerLanguage = 2;
+    int sentencesPerSample = 1;
+    try (LeipzigLanguageSampleStream stream = new LeipzigLanguageSampleStream(
+            emptyTempDir, sentencesPerSample, samplesPerLanguage)) {
 
+      int count = 0;
+      while (stream.read() != null) {
+        count++;
+      }
+      Assertions.assertEquals(0, count);
+    } catch (IOException e) {
+      Assertions.fail();
+    }
   }
 
 }
