@@ -17,7 +17,6 @@
 
 package opennlp.tools.ml;
 
-import java.io.IOException;
 import java.util.Map;
 
 import opennlp.tools.ml.model.DataIndexer;
@@ -28,22 +27,16 @@ import opennlp.tools.util.TrainingParameters;
 
 public class MockEventTrainer implements EventTrainer {
 
-  public MaxentModel train(ObjectStream<Event> events) throws IOException {
+  public MaxentModel train(ObjectStream<Event> events) {
     return null;
   }
 
   @Override
-  public MaxentModel train(DataIndexer indexer) throws IOException {
+  public MaxentModel train(DataIndexer indexer) {
     return null;
   }
 
   @Override
-  public void init(Map<String, String> trainParams,
-      Map<String, String> reportMap) {
-  }
-
-  @Override
-  public void init(TrainingParameters trainingParams,
-      Map<String, String> reportMap) {
+  public void init(TrainingParameters trainingParams, Map<String, String> reportMap) {
   }
 }
