@@ -19,24 +19,20 @@ package opennlp.tools.ml;
 
 import java.util.Map;
 
+import opennlp.tools.commons.Sample;
 import opennlp.tools.ml.model.AbstractModel;
 import opennlp.tools.ml.model.SequenceStream;
 import opennlp.tools.util.TrainingParameters;
 
-public class MockSequenceTrainer implements EventModelSequenceTrainer {
+public class MockSequenceTrainer implements EventModelSequenceTrainer<Sample> {
 
-  public AbstractModel train(SequenceStream events) {
+  @Override
+  public AbstractModel train(SequenceStream<Sample> events) {
     return null;
   }
 
   @Override
-  public void init(Map<String, String> trainParams,
-      Map<String, String> reportMap) {
-  }
-
-  @Override
-  public void init(TrainingParameters trainParams,
-      Map<String, String> reportMap) {
+  public void init(TrainingParameters trainParams, Map<String, String> reportMap) {
   }
   
 }
