@@ -26,10 +26,14 @@ import java.io.StringWriter;
 import java.nio.file.Files;
 import java.nio.file.Path;
 import java.util.HashMap;
+import java.util.stream.Stream;
 
 import org.junit.jupiter.api.Assertions;
 import org.junit.jupiter.api.BeforeEach;
 import org.junit.jupiter.api.Test;
+import org.junit.jupiter.params.ParameterizedTest;
+import org.junit.jupiter.params.provider.Arguments;
+import org.junit.jupiter.params.provider.MethodSource;
 
 import opennlp.tools.ml.AbstractTrainer;
 import opennlp.tools.ml.model.AbstractDataIndexer;
@@ -39,102 +43,51 @@ import opennlp.tools.ml.model.TwoPassDataIndexer;
 import opennlp.tools.util.TrainingParameters;
 
 /**
- * Test for naive bayes classification correctness without smoothing
+ * Test for naive bayes classification correctness without smoothing.
  */
-public class NaiveBayesSerializedCorrectnessTest {
+public class NaiveBayesSerializedCorrectnessTest extends AbstractNaiveBayesTest {
 
   private DataIndexer testDataIndexer;
 
   @BeforeEach
-  void initIndexer() {
+  void initIndexer() throws IOException {
     TrainingParameters trainingParameters = new TrainingParameters();
     trainingParameters.put(AbstractTrainer.CUTOFF_PARAM, 1);
     trainingParameters.put(AbstractDataIndexer.SORT_PARAM, false);
-    ;
     testDataIndexer = new TwoPassDataIndexer();
     testDataIndexer.init(trainingParameters, new HashMap<>());
+    testDataIndexer.index(createTrainingStream());
   }
 
-  @Test
-  void testNaiveBayes1() throws IOException {
-
-    testDataIndexer.index(NaiveBayesCorrectnessTest.createTrainingStream());
-    NaiveBayesModel model1 =
-        (NaiveBayesModel) new NaiveBayesTrainer().trainModel(testDataIndexer);
-
+  @ParameterizedTest
+  @MethodSource("provideLabelsWithContext")
+  void testNaiveBayes(String label, String[] context) throws IOException {
+    NaiveBayesModel model1 = (NaiveBayesModel) new NaiveBayesTrainer().trainModel(testDataIndexer);
     NaiveBayesModel model2 = persistedModel(model1);
-
-    String label = "politics";
-    String[] context = {"bow=united", "bow=nations"};
     Event event = new Event(label, context);
-
     testModelOutcome(model1, model2, event);
-
   }
 
-  @Test
-  void testNaiveBayes2() throws IOException {
-
-    testDataIndexer.index(NaiveBayesCorrectnessTest.createTrainingStream());
-    NaiveBayesModel model1 =
-        (NaiveBayesModel) new NaiveBayesTrainer().trainModel(testDataIndexer);
-
-    NaiveBayesModel model2 = persistedModel(model1);
-
-    String label = "sports";
-    String[] context = {"bow=manchester", "bow=united"};
-    Event event = new Event(label, context);
-
-    testModelOutcome(model1, model2, event);
-
+  /*
+   * Produces a stream of <label|context> pairs for parameterized unit tests.
+   */
+  private static Stream<Arguments> provideLabelsWithContext() {
+    return Stream.of(
+            // Example 1:
+            Arguments.of("politics" , new String[] {"bow=united", "bow=nations"}),
+            Arguments.of("sports",  new String[] {"bow=manchester", "bow=united"}),
+            Arguments.of("politics",  new String[] {"bow=united"}),
+            Arguments.of("politics",  new String[] {})
+    );
   }
 
-  @Test
-  void testNaiveBayes3() throws IOException {
-
-    testDataIndexer.index(NaiveBayesCorrectnessTest.createTrainingStream());
-    NaiveBayesModel model1 =
-        (NaiveBayesModel) new NaiveBayesTrainer().trainModel(testDataIndexer);
-
-    NaiveBayesModel model2 = persistedModel(model1);
-
-    String label = "politics";
-    String[] context = {"bow=united"};
-    Event event = new Event(label, context);
-
-    testModelOutcome(model1, model2, event);
-
-  }
-
-  @Test
-  void testNaiveBayes4() throws IOException {
-
-    testDataIndexer.index(NaiveBayesCorrectnessTest.createTrainingStream());
-    NaiveBayesModel model1 =
-        (NaiveBayesModel) new NaiveBayesTrainer().trainModel(testDataIndexer);
-
-    NaiveBayesModel model2 = persistedModel(model1);
-
-    String label = "politics";
-    String[] context = {};
-    Event event = new Event(label, context);
-
-    testModelOutcome(model1, model2, event);
-
-  }
-
-
   @Test
   void testPlainTextModel() throws IOException {
-    testDataIndexer.index(NaiveBayesCorrectnessTest.createTrainingStream());
-    NaiveBayesModel model1 =
-        (NaiveBayesModel) new NaiveBayesTrainer().trainModel(testDataIndexer);
-
+    NaiveBayesModel model1 = (NaiveBayesModel) new NaiveBayesTrainer().trainModel(testDataIndexer);
 
     StringWriter sw1 = new StringWriter();
 
-    NaiveBayesModelWriter modelWriter =
-        new PlainTextNaiveBayesModelWriter(model1, new BufferedWriter(sw1));
+    NaiveBayesModelWriter modelWriter = new PlainTextNaiveBayesModelWriter(model1, new BufferedWriter(sw1));
     modelWriter.persist();
 
     NaiveBayesModelReader reader =
@@ -147,12 +100,10 @@ public class NaiveBayesSerializedCorrectnessTest {
     modelWriter = new PlainTextNaiveBayesModelWriter(model2, new BufferedWriter(sw2));
     modelWriter.persist();
 
-    System.out.println(sw1.toString());
     Assertions.assertEquals(sw1.toString(), sw2.toString());
-
   }
 
-  protected static NaiveBayesModel persistedModel(NaiveBayesModel model) throws IOException {
+  private static NaiveBayesModel persistedModel(NaiveBayesModel model) throws IOException {
     Path tempFilePath = Files.createTempFile("ptnb-", ".bin");
     File file = tempFilePath.toFile();
     try {
@@ -166,17 +117,15 @@ public class NaiveBayesSerializedCorrectnessTest {
     }
   }
 
-  protected static void testModelOutcome(NaiveBayesModel model1, NaiveBayesModel model2, Event event) {
+  private static void testModelOutcome(NaiveBayesModel model1, NaiveBayesModel model2, Event event) {
     String[] labels1 = extractLabels(model1);
     String[] labels2 = extractLabels(model2);
 
     Assertions.assertArrayEquals(labels1, labels2);
-
     double[] outcomes1 = model1.eval(event.getContext());
     double[] outcomes2 = model2.eval(event.getContext());
 
     Assertions.assertArrayEquals(outcomes1, outcomes2, 0.000000000001);
-
   }
 
   private static String[] extractLabels(NaiveBayesModel model) {
