@@ -17,49 +17,40 @@
 
 package opennlp.tools.parser.treeinsert;
 
-import java.io.ByteArrayInputStream;
-import java.io.ByteArrayOutputStream;
+import java.io.IOException;
 
-import org.junit.jupiter.api.Test;
+import org.junit.jupiter.api.Assertions;
+import org.junit.jupiter.api.BeforeAll;
 
+import opennlp.tools.parser.AbstractParserModelTest;
 import opennlp.tools.parser.HeadRules;
 import opennlp.tools.parser.Parse;
-import opennlp.tools.parser.ParserFactory;
 import opennlp.tools.parser.ParserModel;
 import opennlp.tools.parser.ParserTestUtil;
 import opennlp.tools.util.ObjectStream;
+import opennlp.tools.util.TrainingParameters;
 
 /**
- * Tests for the {@link Parser} class.
+ * Tests for the {@link opennlp.tools.parser.treeinsert.Parser} class.
  */
-public class ParserTest {
+public class ParserTest extends AbstractParserModelTest {
 
-  /**
-   * Verify that training and tagging does not cause
-   * runtime problems.
-   */
-  @Test
-  void testTreeInsertParserTraining() throws Exception {
+  /* Trained dynamically before test */
+  private static ParserModel model;
 
+  @Override
+  protected ParserModel getModel() {
+    return model;
+  }
+  
+  @BeforeAll
+  public static void setupEnvironment() throws IOException {
     ObjectStream<Parse> parseSamples = ParserTestUtil.openTestTrainingData();
     HeadRules headRules = ParserTestUtil.createTestHeadRules();
-
-    ParserModel model = Parser.train("eng", parseSamples, headRules, 100, 0);
-
-    opennlp.tools.parser.Parser parser = ParserFactory.create(model);
-
-    // Tests parsing to make sure the code does not has
-    // a bug which fails always with a runtime exception
-    parser.parse(Parse.parseParse("She was just another freighter from the " +
-        "States and she seemed as commonplace as her name ."));
-
-    // Test serializing and de-serializing model
-    ByteArrayOutputStream outArray = new ByteArrayOutputStream();
-    model.serialize(outArray);
-    outArray.close();
-
-    new ParserModel(new ByteArrayInputStream(outArray.toByteArray()));
-
-    // TODO: compare both models
+    // Training an English lang 'opennlp.tools.parser.treeinsert.Parser'
+    model = Parser.train("eng", parseSamples, headRules, TrainingParameters.defaultParams());
+    Assertions.assertNotNull(model);
+    Assertions.assertFalse(model.isLoadedFromSerialized());
   }
+
 }
