@@ -35,20 +35,14 @@ public class POSDictionaryTest {
   }
 
   private static POSDictionary serializeDeserializeDict(POSDictionary dict) throws IOException {
-    ByteArrayOutputStream out = new ByteArrayOutputStream();
-
-    try {
+    try (ByteArrayOutputStream out = new ByteArrayOutputStream()) {
       dict.serialize(out);
-    } finally {
-      out.close();
+      POSDictionary serializedDictionary;
+      try (InputStream in = new ByteArrayInputStream(out.toByteArray())) {
+        serializedDictionary = POSDictionary.create(in);
+      }
+      return serializedDictionary;
     }
-
-    POSDictionary serializedDictionary;
-    try (InputStream in = new ByteArrayInputStream(out.toByteArray())) {
-      serializedDictionary = POSDictionary.create(in);
-    }
-
-    return serializedDictionary;
   }
 
   @Test
@@ -60,7 +54,7 @@ public class POSDictionaryTest {
     dictionary.put("c", "7", "8", "9");
     dictionary.put("Always", "RB", "NNP");
 
-    Assertions.assertTrue(dictionary.equals(serializeDeserializeDict(dictionary)));
+    Assertions.assertEquals(dictionary, serializeDeserializeDict(dictionary));
   }
 
   @Test
