@@ -65,9 +65,9 @@ public class POSTaggerFactoryTest {
     POSModel posModel = trainPOSModel(new DummyPOSTaggerFactory(posDict));
 
     POSTaggerFactory factory = posModel.getFactory();
-    Assertions.assertTrue(factory.getTagDictionary() instanceof DummyPOSDictionary);
-    Assertions.assertTrue(factory.getPOSContextGenerator() instanceof DummyPOSContextGenerator);
-    Assertions.assertTrue(factory.getSequenceValidator() instanceof DummyPOSSequenceValidator);
+    Assertions.assertInstanceOf(DummyPOSDictionary.class, factory.getTagDictionary());
+    Assertions.assertInstanceOf(DummyPOSContextGenerator.class, factory.getPOSContextGenerator());
+    Assertions.assertInstanceOf(DummyPOSSequenceValidator.class, factory.getSequenceValidator());
 
     ByteArrayOutputStream out = new ByteArrayOutputStream();
     posModel.serialize(out);
@@ -76,9 +76,9 @@ public class POSTaggerFactoryTest {
     POSModel fromSerialized = new POSModel(in);
 
     factory = fromSerialized.getFactory();
-    Assertions.assertTrue(factory.getTagDictionary() instanceof DummyPOSDictionary);
-    Assertions.assertTrue(factory.getPOSContextGenerator() instanceof DummyPOSContextGenerator);
-    Assertions.assertTrue(factory.getSequenceValidator() instanceof DummyPOSSequenceValidator);
+    Assertions.assertInstanceOf(DummyPOSDictionary.class, factory.getTagDictionary());
+    Assertions.assertInstanceOf(DummyPOSContextGenerator.class, factory.getPOSContextGenerator());
+    Assertions.assertInstanceOf(DummyPOSSequenceValidator.class, factory.getSequenceValidator());
   }
 
   @Test
@@ -88,9 +88,9 @@ public class POSTaggerFactoryTest {
     POSModel posModel = trainPOSModel(new POSTaggerFactory(null, null, posDict));
 
     POSTaggerFactory factory = posModel.getFactory();
-    Assertions.assertTrue(factory.getTagDictionary() instanceof POSDictionary);
-    Assertions.assertTrue(factory.getPOSContextGenerator() != null);
-    Assertions.assertTrue(factory.getSequenceValidator() instanceof DefaultPOSSequenceValidator);
+    Assertions.assertInstanceOf(POSDictionary.class, factory.getTagDictionary());
+    Assertions.assertNotNull(factory.getPOSContextGenerator());
+    Assertions.assertInstanceOf(DefaultPOSSequenceValidator.class, factory.getSequenceValidator());
 
     ByteArrayOutputStream out = new ByteArrayOutputStream();
     posModel.serialize(out);
@@ -99,36 +99,30 @@ public class POSTaggerFactoryTest {
     POSModel fromSerialized = new POSModel(in);
 
     factory = fromSerialized.getFactory();
-    Assertions.assertTrue(factory.getTagDictionary() instanceof POSDictionary);
-    Assertions.assertTrue(factory.getPOSContextGenerator() != null);
-    Assertions.assertTrue(factory.getSequenceValidator() instanceof DefaultPOSSequenceValidator);
+    Assertions.assertInstanceOf(POSDictionary.class, factory.getTagDictionary());
+    Assertions.assertNotNull(factory.getPOSContextGenerator());
+    Assertions.assertInstanceOf(DefaultPOSSequenceValidator.class, factory.getSequenceValidator());
   }
 
   @Test
   void testCreateWithInvalidName() {
-    Assertions.assertThrows(InvalidFormatException.class, () -> {
-      BaseToolFactory.create("X", null);
-    });
+    Assertions.assertThrows(InvalidFormatException.class, () -> BaseToolFactory.create("X", null));
   }
 
   @Test
   void testCreateWithInvalidName2() {
-    Assertions.assertThrows(InvalidFormatException.class, () -> {
-      POSTaggerFactory.create("X", null, null);
-    });
+    Assertions.assertThrows(InvalidFormatException.class, () -> POSTaggerFactory.create("X", null, null));
   }
 
   @Test
   void testCreateWithHierarchy() {
-    Assertions.assertThrows(InvalidFormatException.class, () -> {
-      BaseToolFactory.create(Object.class.getCanonicalName(), null);
-    });
+    Assertions.assertThrows(InvalidFormatException.class, () ->
+            BaseToolFactory.create(Object.class.getCanonicalName(), null));
   }
 
   @Test
   void testCreateWithHierarchy2() {
-    Assertions.assertThrows(InvalidFormatException.class, () -> {
-      POSTaggerFactory.create(this.getClass().getCanonicalName(), null, null);
-    });
+    Assertions.assertThrows(InvalidFormatException.class, () ->
+            POSTaggerFactory.create(this.getClass().getCanonicalName(), null, null));
   }
 }
