@@ -80,10 +80,10 @@ public class SentenceSampleTest {
 
   @Test
   void testEquals() {
-    Assertions.assertFalse(createGoldSample() == createGoldSample());
-    Assertions.assertTrue(createGoldSample().equals(createGoldSample()));
-    Assertions.assertFalse(createPredSample().equals(createGoldSample()));
-    Assertions.assertFalse(createPredSample().equals(new Object()));
+    Assertions.assertNotSame(createGoldSample(), createGoldSample());
+    Assertions.assertEquals(createGoldSample(), createGoldSample());
+    Assertions.assertNotEquals(createPredSample(), createGoldSample());
+    Assertions.assertNotEquals(createPredSample(), new Object());
   }
 
   public static SentenceSample createGoldSample() {
