@@ -16,8 +16,8 @@
  */
 package opennlp.tools.util.normalizer;
 
-import org.junit.Assert;
-import org.junit.Test;
+import org.junit.jupiter.api.Assertions;
+import org.junit.jupiter.api.Test;
 
 
 public class NumberCharSequenceNormalizerTest {
@@ -26,7 +26,7 @@ public class NumberCharSequenceNormalizerTest {
 
 
   @Test
-  public void normalize() throws Exception {
-    Assert.assertEquals("absc  ,  abcd", normalizer.normalize("absc 123,0123 abcd"));
+  void normalize() {
+    Assertions.assertEquals("absc  ,  abcd", normalizer.normalize("absc 123,0123 abcd"));
   }
 }
